@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -34,14 +34,18 @@
 
 /**
  * Structure for CSeq headers.
- * @defvar osip_cseq_t
+ * @var osip_cseq_t
  */
   typedef struct osip_cseq osip_cseq_t;
 
+/**
+ * Definition of the CSeq header.
+ * @struct osip_cseq
+ */
   struct osip_cseq
   {
-    char *method;
-    char *number;
+    char *method;    /**< CSeq method */
+    char *number;    /**< CSeq number */
   };
 
 #ifdef __cplusplus
