@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -37,15 +37,19 @@
 
 /**
  * Structure for From headers.
- * @defvar osip_from_t
+ * @var osip_from_t
  */
   typedef struct osip_from osip_from_t;
 
+/**
+ * Definition of the From header.
+ * @struct osip_from
+ */
   struct osip_from
   {
-    char *displayname;
-    osip_uri_t *url;			/* could contain various urischeme_t ? only in the future */
-    osip_list_t *gen_params;
+    char *displayname;       /**< Display Name */ 
+    osip_uri_t *url;         /**< url */
+    osip_list_t *gen_params; /**< other From parameters */
   };
 
 #ifdef __cplusplus
