@@ -74,8 +74,8 @@ typedef struct _transition_t
 transition_t;
 
 int fsm_callmethod (type_t type, state_t state,
-		    osip_statemachine_t * statemachine,
-		    void *sipevent, void *transaction);
+                    osip_statemachine_t * statemachine,
+                    void *sipevent, void *transaction);
 
 
 /*!! THESE ARE FOR INTERNAL USE ONLY!! */
@@ -93,7 +93,7 @@ void osip_ict_timeout_d_event (osip_transaction_t * ict, osip_event_t * evt);
 void ict_rcv_1xx (osip_transaction_t * ict, osip_event_t * evt);
 void ict_rcv_2xx (osip_transaction_t * ict, osip_event_t * evt);
 osip_message_t *ict_create_ack (osip_transaction_t * ict,
-				osip_message_t * response);
+                                osip_message_t * response);
 void ict_rcv_3456xx (osip_transaction_t * ict, osip_event_t * evt);
 void ict_retransmit_ack (osip_transaction_t * ict, osip_event_t * evt);
 
@@ -102,7 +102,7 @@ void ict_retransmit_ack (osip_transaction_t * ict, osip_event_t * evt);
 /************************/
 
 osip_message_t *ist_create_resp_100 (osip_transaction_t * ist,
-				     osip_message_t * request);
+                                     osip_message_t * request);
 void ist_rcv_invite (osip_transaction_t * ist, osip_event_t * evt);
 void osip_ist_timeout_g_event (osip_transaction_t * ist, osip_event_t * evt);
 void osip_ist_timeout_h_event (osip_transaction_t * ist, osip_event_t * evt);
@@ -117,12 +117,9 @@ void ist_rcv_ack (osip_transaction_t * ist, osip_event_t * evt);
 /***********************/
 
 void nict_snd_request (osip_transaction_t * nict, osip_event_t * evt);
-void osip_nict_timeout_e_event (osip_transaction_t * nict,
-				osip_event_t * evt);
-void osip_nict_timeout_f_event (osip_transaction_t * nict,
-				osip_event_t * evt);
-void osip_nict_timeout_k_event (osip_transaction_t * nict,
-				osip_event_t * evt);
+void osip_nict_timeout_e_event (osip_transaction_t * nict, osip_event_t * evt);
+void osip_nict_timeout_f_event (osip_transaction_t * nict, osip_event_t * evt);
+void osip_nict_timeout_k_event (osip_transaction_t * nict, osip_event_t * evt);
 void nict_rcv_1xx (osip_transaction_t * nict, osip_event_t * evt);
 void nict_rcv_23456xx (osip_transaction_t * nict, osip_event_t * evt);
 
@@ -135,19 +132,16 @@ void nict_rcv_23456xx (osip_transaction_t * nict, osip_event_t * evt);
 void nist_rcv_request (osip_transaction_t * nist, osip_event_t * evt);
 void nist_snd_1xx (osip_transaction_t * nist, osip_event_t * evt);
 void nist_snd_23456xx (osip_transaction_t * nist, osip_event_t * evt);
-void osip_nist_timeout_j_event (osip_transaction_t * nist,
-				osip_event_t * evt);
+void osip_nist_timeout_j_event (osip_transaction_t * nist, osip_event_t * evt);
 
 /************************/
 /* Internal Methods     */
 /************************/
 
 
-void __osip_message_callback (int type, osip_transaction_t *,
-			      osip_message_t *);
+void __osip_message_callback (int type, osip_transaction_t *, osip_message_t *);
 void __osip_kill_transaction_callback (int type, osip_transaction_t *);
-void __osip_transport_error_callback (int type, osip_transaction_t *,
-				      int error);
+void __osip_transport_error_callback (int type, osip_transaction_t *, int error);
 
 /**
  * Set the state of the transaction.
@@ -155,8 +149,7 @@ void __osip_transport_error_callback (int type, osip_transaction_t *,
  * @param transaction The element to work on.
  * @param state The new state.
  */
-int __osip_transaction_set_state (osip_transaction_t * transaction,
-				  state_t state);
+int __osip_transaction_set_state (osip_transaction_t * transaction, state_t state);
 
 /**
  * Check if the response match a server transaction.
@@ -166,9 +159,8 @@ int __osip_transaction_set_state (osip_transaction_t * transaction,
  */
 int
 __osip_transaction_matching_response_osip_to_xict_17_1_3 (osip_transaction_t *
-							  tr,
-							  osip_message_t *
-							  resp);
+                                                          tr,
+                                                          osip_message_t * resp);
 
 /**
  * Check if the request match a client transaction.
@@ -178,9 +170,8 @@ __osip_transaction_matching_response_osip_to_xict_17_1_3 (osip_transaction_t *
  */
 int
 __osip_transaction_matching_request_osip_to_xist_17_2_3 (osip_transaction_t *
-							 tr,
-							 osip_message_t *
-							 request);
+                                                         tr,
+                                                         osip_message_t * request);
 
 #endif
 
