@@ -38,8 +38,7 @@ __ist_unload_fsm ()
 
   while (!osip_list_eol (statemachine->transitions, 0))
     {
-      transition =
-	(transition_t *) osip_list_get (statemachine->transitions, 0);
+      transition = (transition_t *) osip_list_get (statemachine->transitions, 0);
       osip_list_remove (statemachine->transitions, 0);
       osip_free (transition);
     }
@@ -53,8 +52,7 @@ __ist_load_fsm ()
 {
   transition_t *transition;
 
-  ist_fsm =
-    (osip_statemachine_t *) osip_malloc (sizeof (osip_statemachine_t));
+  ist_fsm = (osip_statemachine_t *) osip_malloc (sizeof (osip_statemachine_t));
   ist_fsm->transitions = (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   osip_list_init (ist_fsm->transitions);
 
@@ -141,7 +139,7 @@ ist_create_resp_100 (osip_transaction_t * ist, osip_message_t * request)
   if (i != 0)
     goto icr_error;
   /* 17.2.1 says: should NOT add a tag */
-  i = osip_to_clone (request->to, &(resp_100->to));	/* DOES NOT include any tag! */
+  i = osip_to_clone (request->to, &(resp_100->to));     /* DOES NOT include any tag! */
   if (i != 0)
     goto icr_error;
   i = osip_call_id_clone (request->call_id, &(resp_100->call_id));
@@ -159,11 +157,10 @@ ist_create_resp_100 (osip_transaction_t * ist, osip_message_t * request)
 
     while (!osip_list_eol (ist->orig_request->vias, pos))
       {
-	orig_via =
-	  (osip_via_t *) osip_list_get (ist->orig_request->vias, pos);
-	osip_via_clone (orig_via, &via);
-	osip_list_add (resp_100->vias, via, -1);
-	pos++;
+        orig_via = (osip_via_t *) osip_list_get (ist->orig_request->vias, pos);
+        osip_via_clone (orig_via, &via);
+        osip_list_add (resp_100->vias, via, -1);
+        pos++;
       }
   }
 
@@ -193,83 +190,80 @@ ist_rcv_invite (osip_transaction_t * ist, osip_event_t * evt)
   int i;
   osip_t *osip = (osip_t *) ist->config;
 
-  if (ist->state == IST_PRE_PROCEEDING)	/* announce new INVITE */
+  if (ist->state == IST_PRE_PROCEEDING) /* announce new INVITE */
     {
       /* Here we have ist->orig_request == NULL */
       ist->orig_request = evt->sip;
 
       __osip_message_callback (OSIP_IST_INVITE_RECEIVED, ist, evt->sip);
-    }
-  else				/* IST_PROCEEDING or IST_COMPLETED */
+  } else                        /* IST_PROCEEDING or IST_COMPLETED */
     {
       /* delete retransmission */
       osip_message_free (evt->sip);
 
       __osip_message_callback (OSIP_IST_INVITE_RECEIVED_AGAIN, ist,
-			       ist->orig_request);
-      if (ist->last_response != NULL)	/* retransmit last response */
-	{
-	  osip_via_t *via;
+                               ist->orig_request);
+      if (ist->last_response != NULL)   /* retransmit last response */
+        {
+          osip_via_t *via;
 
-	  via = (osip_via_t *) osip_list_get (ist->last_response->vias, 0);
-	  if (via)
-	    {
-	      char *host;
-	      int port;
-	      osip_generic_param_t *maddr;
-	      osip_generic_param_t *received;
-	      osip_generic_param_t *rport;
-	      osip_via_param_get_byname (via, "maddr", &maddr);
-	      osip_via_param_get_byname (via, "received", &received);
-	      osip_via_param_get_byname (via, "rport", &rport);
-	      /* 1: user should not use the provided information
-	         (host and port) if they are using a reliable
-	         transport. Instead, they should use the already
-	         open socket attached to this transaction. */
-	      /* 2: check maddr and multicast usage */
-	      if (maddr != NULL)
-		host = maddr->gvalue;
-	      /* we should check if this is a multicast address and use
-	         set the "ttl" in this case. (this must be done in the
-	         UDP message (not at the SIP layer) */
-	      else if (received != NULL)
-		host = received->gvalue;
-	      else
-		host = via->host;
+          via = (osip_via_t *) osip_list_get (ist->last_response->vias, 0);
+          if (via)
+            {
+              char *host;
+              int port;
+              osip_generic_param_t *maddr;
+              osip_generic_param_t *received;
+              osip_generic_param_t *rport;
 
-	      if (rport == NULL || rport->gvalue == NULL)
-		{
-		  if (via->port != NULL)
-		    port = osip_atoi (via->port);
-		  else
-		    port = 5060;
-		}
-	      else
-		port = osip_atoi (rport->gvalue);
+              osip_via_param_get_byname (via, "maddr", &maddr);
+              osip_via_param_get_byname (via, "received", &received);
+              osip_via_param_get_byname (via, "rport", &rport);
+              /* 1: user should not use the provided information
+                 (host and port) if they are using a reliable
+                 transport. Instead, they should use the already
+                 open socket attached to this transaction. */
+              /* 2: check maddr and multicast usage */
+              if (maddr != NULL)
+                host = maddr->gvalue;
+              /* we should check if this is a multicast address and use
+                 set the "ttl" in this case. (this must be done in the
+                 UDP message (not at the SIP layer) */
+              else if (received != NULL)
+                host = received->gvalue;
+              else
+                host = via->host;
 
-	      i = osip->cb_send_message (ist, ist->last_response, host,
-					 port, ist->out_socket);
-	    }
-	  else
-	    i = -1;
-	  if (i != 0)
-	    {
-	      ist_handle_transport_error (ist, i);
-	      return;
-	    }
-	  else
-	    {
-	      if (MSG_IS_STATUS_1XX (ist->last_response))
-		__osip_message_callback (OSIP_IST_STATUS_1XX_SENT, ist,
-					 ist->last_response);
-	      else if (MSG_IS_STATUS_2XX (ist->last_response))
-		__osip_message_callback (OSIP_IST_STATUS_2XX_SENT_AGAIN, ist,
-					 ist->last_response);
-	      else
-		__osip_message_callback (OSIP_IST_STATUS_3456XX_SENT_AGAIN,
-					 ist, ist->last_response);
-	    }
-	}
+              if (rport == NULL || rport->gvalue == NULL)
+                {
+                  if (via->port != NULL)
+                    port = osip_atoi (via->port);
+                  else
+                    port = 5060;
+              } else
+                port = osip_atoi (rport->gvalue);
+
+              i = osip->cb_send_message (ist, ist->last_response, host,
+                                         port, ist->out_socket);
+          } else
+            i = -1;
+          if (i != 0)
+            {
+              ist_handle_transport_error (ist, i);
+              return;
+          } else
+            {
+              if (MSG_IS_STATUS_1XX (ist->last_response))
+                __osip_message_callback (OSIP_IST_STATUS_1XX_SENT, ist,
+                                         ist->last_response);
+              else if (MSG_IS_STATUS_2XX (ist->last_response))
+                __osip_message_callback (OSIP_IST_STATUS_2XX_SENT_AGAIN, ist,
+                                         ist->last_response);
+              else
+                __osip_message_callback (OSIP_IST_STATUS_3456XX_SENT_AGAIN,
+                                         ist, ist->last_response);
+            }
+        }
       return;
     }
 
@@ -289,7 +283,7 @@ osip_ist_timeout_g_event (osip_transaction_t * ist, osip_event_t * evt)
     ist->ist_context->timer_g_length = 4000;
   osip_gettimeofday (&ist->ist_context->timer_g_start, NULL);
   add_gettimeofday (&ist->ist_context->timer_g_start,
-		    ist->ist_context->timer_g_length);
+                    ist->ist_context->timer_g_length);
 
   /* retransmit RESPONSE */
   via = (osip_via_t *) osip_list_get (ist->last_response->vias, 0);
@@ -300,6 +294,7 @@ osip_ist_timeout_g_event (osip_transaction_t * ist, osip_event_t * evt)
       osip_generic_param_t *maddr;
       osip_generic_param_t *received;
       osip_generic_param_t *rport;
+
       osip_via_param_get_byname (via, "maddr", &maddr);
       osip_via_param_get_byname (via, "received", &received);
       osip_via_param_get_byname (via, "rport", &rport);
@@ -309,29 +304,27 @@ osip_ist_timeout_g_event (osip_transaction_t * ist, osip_event_t * evt)
          open socket attached to this transaction. */
       /* 2: check maddr and multicast usage */
       if (maddr != NULL)
-	host = maddr->gvalue;
+        host = maddr->gvalue;
       /* we should check if this is a multicast address and use
          set the "ttl" in this case. (this must be done in the
          UDP message (not at the SIP layer) */
       else if (received != NULL)
-	host = received->gvalue;
+        host = received->gvalue;
       else
-	host = via->host;
+        host = via->host;
 
       if (rport == NULL || rport->gvalue == NULL)
-	{
-	  if (via->port != NULL)
-	    port = osip_atoi (via->port);
-	  else
-	    port = 5060;
-	}
-      else
-	port = osip_atoi (rport->gvalue);
+        {
+          if (via->port != NULL)
+            port = osip_atoi (via->port);
+          else
+            port = 5060;
+      } else
+        port = osip_atoi (rport->gvalue);
 
       i = osip->cb_send_message (ist, ist->last_response, host,
-				 port, ist->out_socket);
-    }
-  else
+                                 port, ist->out_socket);
+  } else
     i = -1;
   if (i != 0)
     {
@@ -339,7 +332,7 @@ osip_ist_timeout_g_event (osip_transaction_t * ist, osip_event_t * evt)
       return;
     }
   __osip_message_callback (OSIP_IST_STATUS_3456XX_SENT_AGAIN, ist,
-			   ist->last_response);
+                           ist->last_response);
 }
 
 void
@@ -383,6 +376,7 @@ ist_snd_1xx (osip_transaction_t * ist, osip_event_t * evt)
       osip_generic_param_t *maddr;
       osip_generic_param_t *received;
       osip_generic_param_t *rport;
+
       osip_via_param_get_byname (via, "maddr", &maddr);
       osip_via_param_get_byname (via, "received", &received);
       osip_via_param_get_byname (via, "rport", &rport);
@@ -392,38 +386,34 @@ ist_snd_1xx (osip_transaction_t * ist, osip_event_t * evt)
          open socket attached to this transaction. */
       /* 2: check maddr and multicast usage */
       if (maddr != NULL)
-	host = maddr->gvalue;
+        host = maddr->gvalue;
       /* we should check if this is a multicast address and use
          set the "ttl" in this case. (this must be done in the
          UDP message (not at the SIP layer) */
       else if (received != NULL)
-	host = received->gvalue;
+        host = received->gvalue;
       else
-	host = via->host;
+        host = via->host;
 
       if (rport == NULL || rport->gvalue == NULL)
-	{
-	  if (via->port != NULL)
-	    port = osip_atoi (via->port);
-	  else
-	    port = 5060;
-	}
-      else
-	port = osip_atoi (rport->gvalue);
+        {
+          if (via->port != NULL)
+            port = osip_atoi (via->port);
+          else
+            port = 5060;
+      } else
+        port = osip_atoi (rport->gvalue);
 
       i = osip->cb_send_message (ist, ist->last_response, host,
-				 port, ist->out_socket);
-    }
-  else
+                                 port, ist->out_socket);
+  } else
     i = -1;
   if (i != 0)
     {
       ist_handle_transport_error (ist, i);
       return;
-    }
-  else
-    __osip_message_callback (OSIP_IST_STATUS_1XX_SENT, ist,
-			     ist->last_response);
+  } else
+    __osip_message_callback (OSIP_IST_STATUS_1XX_SENT, ist, ist->last_response);
 
   /* we are already in the proper state */
   return;
@@ -450,6 +440,7 @@ ist_snd_2xx (osip_transaction_t * ist, osip_event_t * evt)
       osip_generic_param_t *maddr;
       osip_generic_param_t *received;
       osip_generic_param_t *rport;
+
       osip_via_param_get_byname (via, "maddr", &maddr);
       osip_via_param_get_byname (via, "received", &received);
       osip_via_param_get_byname (via, "rport", &rport);
@@ -459,38 +450,34 @@ ist_snd_2xx (osip_transaction_t * ist, osip_event_t * evt)
          open socket attached to this transaction. */
       /* 2: check maddr and multicast usage */
       if (maddr != NULL)
-	host = maddr->gvalue;
+        host = maddr->gvalue;
       /* we should check if this is a multicast address and use
          set the "ttl" in this case. (this must be done in the
          UDP message (not at the SIP layer) */
       else if (received != NULL)
-	host = received->gvalue;
+        host = received->gvalue;
       else
-	host = via->host;
+        host = via->host;
 
       if (rport == NULL || rport->gvalue == NULL)
-	{
-	  if (via->port != NULL)
-	    port = osip_atoi (via->port);
-	  else
-	    port = 5060;
-	}
-      else
-	port = osip_atoi (rport->gvalue);
+        {
+          if (via->port != NULL)
+            port = osip_atoi (via->port);
+          else
+            port = 5060;
+      } else
+        port = osip_atoi (rport->gvalue);
       i = osip->cb_send_message (ist, ist->last_response, host,
-				 port, ist->out_socket);
-    }
-  else
+                                 port, ist->out_socket);
+  } else
     i = -1;
   if (i != 0)
     {
       ist_handle_transport_error (ist, i);
       return;
-    }
-  else
+  } else
     {
-      __osip_message_callback (OSIP_IST_STATUS_2XX_SENT, ist,
-			       ist->last_response);
+      __osip_message_callback (OSIP_IST_STATUS_2XX_SENT, ist, ist->last_response);
       __osip_transaction_set_state (ist, IST_TERMINATED);
       __osip_kill_transaction_callback (OSIP_IST_KILL_TRANSACTION, ist);
     }
@@ -518,6 +505,7 @@ ist_snd_3456xx (osip_transaction_t * ist, osip_event_t * evt)
       osip_generic_param_t *maddr;
       osip_generic_param_t *received;
       osip_generic_param_t *rport;
+
       osip_via_param_get_byname (via, "maddr", &maddr);
       osip_via_param_get_byname (via, "received", &received);
       osip_via_param_get_byname (via, "rport", &rport);
@@ -527,59 +515,56 @@ ist_snd_3456xx (osip_transaction_t * ist, osip_event_t * evt)
          open socket attached to this transaction. */
       /* 2: check maddr and multicast usage */
       if (maddr != NULL)
-	host = maddr->gvalue;
+        host = maddr->gvalue;
       /* we should check if this is a multicast address and use
          set the "ttl" in this case. (this must be done in the
          UDP message (not at the SIP layer) */
       else if (received != NULL)
-	host = received->gvalue;
+        host = received->gvalue;
       else
-	host = via->host;
+        host = via->host;
 
       if (rport == NULL || rport->gvalue == NULL)
-	{
-	  if (via->port != NULL)
-	    port = osip_atoi (via->port);
-	  else
-	    port = 5060;
-	}
-      else
-	port = osip_atoi (rport->gvalue);
+        {
+          if (via->port != NULL)
+            port = osip_atoi (via->port);
+          else
+            port = 5060;
+      } else
+        port = osip_atoi (rport->gvalue);
       i = osip->cb_send_message (ist, ist->last_response, host,
-				 port, ist->out_socket);
-    }
-  else
+                                 port, ist->out_socket);
+  } else
     i = -1;
   if (i != 0)
     {
       ist_handle_transport_error (ist, i);
       return;
-    }
-  else
+  } else
     {
       if (MSG_IS_STATUS_3XX (ist->last_response))
-	__osip_message_callback (OSIP_IST_STATUS_3XX_SENT, ist,
-				 ist->last_response);
+        __osip_message_callback (OSIP_IST_STATUS_3XX_SENT, ist,
+                                 ist->last_response);
       else if (MSG_IS_STATUS_4XX (ist->last_response))
-	__osip_message_callback (OSIP_IST_STATUS_4XX_SENT, ist,
-				 ist->last_response);
+        __osip_message_callback (OSIP_IST_STATUS_4XX_SENT, ist,
+                                 ist->last_response);
       else if (MSG_IS_STATUS_5XX (ist->last_response))
-	__osip_message_callback (OSIP_IST_STATUS_5XX_SENT, ist,
-				 ist->last_response);
+        __osip_message_callback (OSIP_IST_STATUS_5XX_SENT, ist,
+                                 ist->last_response);
       else
-	__osip_message_callback (OSIP_IST_STATUS_6XX_SENT, ist,
-				 ist->last_response);
+        __osip_message_callback (OSIP_IST_STATUS_6XX_SENT, ist,
+                                 ist->last_response);
     }
 
-  if(ist->ist_context->timer_g_length != -1)
+  if (ist->ist_context->timer_g_length != -1)
     {
       osip_gettimeofday (&ist->ist_context->timer_g_start, NULL);
       add_gettimeofday (&ist->ist_context->timer_g_start,
-			ist->ist_context->timer_g_length);
+                        ist->ist_context->timer_g_length);
     }
   osip_gettimeofday (&ist->ist_context->timer_h_start, NULL);
   add_gettimeofday (&ist->ist_context->timer_h_start,
-		    ist->ist_context->timer_h_length);
+                    ist->ist_context->timer_h_length);
   __osip_transaction_set_state (ist, IST_COMPLETED);
   return;
 }
@@ -596,11 +581,11 @@ ist_rcv_ack (osip_transaction_t * ist, osip_event_t * evt)
 
   if (ist->state == IST_COMPLETED)
     __osip_message_callback (OSIP_IST_ACK_RECEIVED, ist, ist->ack);
-  else				/* IST_CONFIRMED */
+  else                          /* IST_CONFIRMED */
     __osip_message_callback (OSIP_IST_ACK_RECEIVED_AGAIN, ist, ist->ack);
   /* set the timer to 0 for reliable, and T4 for unreliable (already set) */
   osip_gettimeofday (&ist->ist_context->timer_i_start, NULL);
   add_gettimeofday (&ist->ist_context->timer_i_start,
-		    ist->ist_context->timer_i_length);
+                    ist->ist_context->timer_i_length);
   __osip_transaction_set_state (ist, IST_CONFIRMED);
 }
