@@ -28,13 +28,13 @@ void
 osip_dialog_set_state (osip_dialog_t * dialog, state_t state)
 {
   if (dialog == NULL)
-    return ;
+    return;
   dialog->state = state;
 }
 
 int
 osip_dialog_update_route_set_as_uas (osip_dialog_t * dialog,
-				     osip_message_t * invite)
+                                     osip_message_t * invite)
 {
   osip_contact_t *contact;
   int i;
@@ -47,33 +47,30 @@ osip_dialog_update_route_set_as_uas (osip_dialog_t * dialog,
   if (osip_list_eol (invite->contacts, 0))
     {
       OSIP_TRACE (osip_trace
-		  (__FILE__, __LINE__, OSIP_WARNING, NULL,
-		   "missing a contact in invite!\n"));
-    }
-  else
+                  (__FILE__, __LINE__, OSIP_WARNING, NULL,
+                   "missing a contact in invite!\n"));
+  } else
     {
       if (dialog->remote_contact_uri != NULL)
-	{
-	  osip_contact_free (dialog->remote_contact_uri);
-	}
+        {
+          osip_contact_free (dialog->remote_contact_uri);
+        }
       dialog->remote_contact_uri = NULL;
       contact = osip_list_get (invite->contacts, 0);
       i = osip_contact_clone (contact, &(dialog->remote_contact_uri));
       if (i != 0)
-	return -1;
+        return -1;
     }
   return 0;
 }
 
 int
 osip_dialog_update_osip_cseq_as_uas (osip_dialog_t * dialog,
-				     osip_message_t * invite)
+                                     osip_message_t * invite)
 {
   if (dialog == NULL)
     return -1;
-  if (invite == NULL ||
-      invite->cseq == NULL ||
-      invite->cseq->number == NULL)
+  if (invite == NULL || invite->cseq == NULL || invite->cseq->number == NULL)
     return -1;
 
   dialog->remote_cseq = osip_atoi (invite->cseq->number);
@@ -82,7 +79,7 @@ osip_dialog_update_osip_cseq_as_uas (osip_dialog_t * dialog,
 
 int
 osip_dialog_update_route_set_as_uac (osip_dialog_t * dialog,
-				     osip_message_t * response)
+                                     osip_message_t * response)
 {
   /* only the remote target URI is updated here... */
   osip_contact_t *contact;
@@ -94,45 +91,46 @@ osip_dialog_update_route_set_as_uac (osip_dialog_t * dialog,
     return -1;
 
   if (osip_list_eol (response->contacts, 0))
-    {				/* no contact header in response? */
+    {                           /* no contact header in response? */
       OSIP_TRACE (osip_trace
-		  (__FILE__, __LINE__, OSIP_WARNING, NULL,
-		   "missing a contact in response!\n"));
-    }
-  else
+                  (__FILE__, __LINE__, OSIP_WARNING, NULL,
+                   "missing a contact in response!\n"));
+  } else
     {
       /* I personally think it's a bad idea to keep the old
          value in case the new one is broken... */
       if (dialog->remote_contact_uri != NULL)
-	{
-	  osip_contact_free (dialog->remote_contact_uri);
-	}
+        {
+          osip_contact_free (dialog->remote_contact_uri);
+        }
       dialog->remote_contact_uri = NULL;
       contact = osip_list_get (response->contacts, 0);
       i = osip_contact_clone (contact, &(dialog->remote_contact_uri));
       if (i != 0)
-	return -1;
+        return -1;
     }
 
-  if (dialog->state == DIALOG_EARLY
-      && osip_list_size (dialog->route_set) == 0)
-    {				/* update the route set */
+  if (dialog->state == DIALOG_EARLY && osip_list_size (dialog->route_set) == 0)
+    {                           /* update the route set */
       int pos = 0;
 
       while (!osip_list_eol (response->record_routes, pos))
-	{
-	  osip_record_route_t *rr;
-	  osip_record_route_t *rr2;
+        {
+          osip_record_route_t *rr;
+          osip_record_route_t *rr2;
 
-	  rr =
-	    (osip_record_route_t *) osip_list_get (response->record_routes,
-						   pos);
-	  i = osip_record_route_clone (rr, &rr2);
-	  if (i != 0)
-	    return -1;
-	  osip_list_add (dialog->route_set, rr2, -1);
-	  pos++;
-	}
+          rr =
+            (osip_record_route_t *) osip_list_get (response->record_routes, pos);
+          i = osip_record_route_clone (rr, &rr2);
+          if (i != 0)
+            return -1;
+#ifdef OSIP_FUTURE_FIX_2_3
+          osip_list_add (dialog->route_set, rr2, 0);
+#else
+          osip_list_add (dialog->route_set, rr2, -1);
+#endif
+          pos++;
+        }
     }
 
   if (MSG_IS_STATUS_2XX (response))
@@ -141,8 +139,7 @@ osip_dialog_update_route_set_as_uac (osip_dialog_t * dialog,
 }
 
 int
-osip_dialog_update_tag_as_uac (osip_dialog_t * dialog,
-			       osip_message_t * response)
+osip_dialog_update_tag_as_uac (osip_dialog_t * dialog, osip_message_t * response)
 {
   osip_generic_param_t *tag;
   int i;
@@ -153,14 +150,13 @@ osip_dialog_update_tag_as_uac (osip_dialog_t * dialog,
     return -1;
 
   i = osip_to_get_tag (response->to, &tag);
-  if (i != 0 || tag==NULL || tag->gvalue==NULL)
+  if (i != 0 || tag == NULL || tag->gvalue == NULL)
     {
       OSIP_TRACE (osip_trace
-		  (__FILE__, __LINE__, OSIP_WARNING, NULL,
-		   "Remote UA is not compliant: missing a tag in response!\n"));
+                  (__FILE__, __LINE__, OSIP_WARNING, NULL,
+                   "Remote UA is not compliant: missing a tag in response!\n"));
       dialog->remote_tag = NULL;
-    }
-  else
+  } else
     dialog->remote_tag = osip_strdup (tag->gvalue);
   return 0;
 }
@@ -175,25 +171,25 @@ osip_dialog_match_as_uac (osip_dialog_t * dlg, osip_message_t * answer)
 
   if (dlg == NULL)
     return -1;
-  if (answer == NULL || answer->call_id==NULL ||
-      answer->from==NULL || answer->to==NULL)
+  if (answer == NULL || answer->call_id == NULL ||
+      answer->from == NULL || answer->to == NULL)
     return -1;
 
   OSIP_TRACE (osip_trace
-	      (__FILE__, __LINE__, OSIP_WARNING, NULL,
-	       "Using this method is discouraged. See source code explanations!\n"));
+              (__FILE__, __LINE__, OSIP_WARNING, NULL,
+               "Using this method is discouraged. See source code explanations!\n"));
   /*
-    When starting a new transaction and when receiving several answers,
-    you must be prepared to receive several answers from different sources.
-    (because of forking).
+     When starting a new transaction and when receiving several answers,
+     you must be prepared to receive several answers from different sources.
+     (because of forking).
 
-    Because some UAs are not compliant (a to tag is missing!), this method
-    may match the wrong dialog when a dialog has been created with an empty
-    tag in the To header.
+     Because some UAs are not compliant (a to tag is missing!), this method
+     may match the wrong dialog when a dialog has been created with an empty
+     tag in the To header.
 
-    Personnaly, I would recommend to discard 1xx>=101 answers without To tags!
-    Just my own feelings.
-  */
+     Personnaly, I would recommend to discard 1xx>=101 answers without To tags!
+     Just my own feelings.
+   */
   osip_call_id_to_str (answer->call_id, &tmp);
   if (0 != strcmp (dlg->call_id, tmp))
     {
@@ -216,28 +212,28 @@ osip_dialog_match_as_uac (osip_dialog_t * dlg, osip_message_t * answer)
     return -1;
 
   i = osip_to_get_tag (answer->to, &tag_param_remote);
-  if (i != 0 && dlg->remote_tag != NULL)	/* no tag in response but tag in dialog */
-    return -1;			/* impossible... */
-  if (i != 0 && dlg->remote_tag == NULL)	/* no tag in response AND no tag in dialog */
+  if (i != 0 && dlg->remote_tag != NULL)        /* no tag in response but tag in dialog */
+    return -1;                  /* impossible... */
+  if (i != 0 && dlg->remote_tag == NULL)        /* no tag in response AND no tag in dialog */
     {
       if (0 ==
-	  osip_from_compare ((osip_from_t *) dlg->local_uri,
-			     (osip_from_t *) answer->from)
-	  && 0 == osip_from_compare (dlg->remote_uri, answer->to))
-	return 0;
+          osip_from_compare ((osip_from_t *) dlg->local_uri,
+                             (osip_from_t *) answer->from)
+          && 0 == osip_from_compare (dlg->remote_uri, answer->to))
+        return 0;
       return -1;
     }
 
-  if (dlg->remote_tag == NULL)	/* tag in response BUT no tag in dialog */
+  if (dlg->remote_tag == NULL)  /* tag in response BUT no tag in dialog */
     {
       OSIP_TRACE (osip_trace
-		  (__FILE__, __LINE__, OSIP_WARNING, NULL,
-		   "Remote UA is not compliant: missing a tag in To fields!\n"));
+                  (__FILE__, __LINE__, OSIP_WARNING, NULL,
+                   "Remote UA is not compliant: missing a tag in To fields!\n"));
       if (0 ==
-	  osip_from_compare ((osip_from_t *) dlg->local_uri,
-			     (osip_from_t *) answer->from)
-	  && 0 == osip_from_compare (dlg->remote_uri, answer->to))
-	return 0;
+          osip_from_compare ((osip_from_t *) dlg->local_uri,
+                             (osip_from_t *) answer->from)
+          && 0 == osip_from_compare (dlg->remote_uri, answer->to))
+        return 0;
       return -1;
     }
 
@@ -259,8 +255,8 @@ osip_dialog_match_as_uas (osip_dialog_t * dlg, osip_message_t * request)
 
   if (dlg == NULL)
     return -1;
-  if (request == NULL || request->call_id==NULL ||
-      request->from==NULL || request->to==NULL)
+  if (request == NULL || request->call_id == NULL ||
+      request->from == NULL || request->to == NULL)
     return -1;
 
   osip_call_id_to_str (request->call_id, &tmp);
@@ -281,28 +277,28 @@ osip_dialog_match_as_uas (osip_dialog_t * dlg, osip_message_t * request)
     return -1;
 
   i = osip_from_get_tag (request->from, &tag_param_remote);
-  if (i != 0 && dlg->remote_tag != NULL)	/* no tag in request but tag in dialog */
-    return -1;			/* impossible... */
-  if (i != 0 && dlg->remote_tag == NULL)	/* no tag in request AND no tag in dialog */
+  if (i != 0 && dlg->remote_tag != NULL)        /* no tag in request but tag in dialog */
+    return -1;                  /* impossible... */
+  if (i != 0 && dlg->remote_tag == NULL)        /* no tag in request AND no tag in dialog */
     {
       if (0 ==
-	  osip_from_compare ((osip_from_t *) dlg->remote_uri,
-			     (osip_from_t *) request->from)
-	  && 0 == osip_from_compare (dlg->local_uri, request->to))
-	return 0;
+          osip_from_compare ((osip_from_t *) dlg->remote_uri,
+                             (osip_from_t *) request->from)
+          && 0 == osip_from_compare (dlg->local_uri, request->to))
+        return 0;
       return -1;
     }
 
-  if (dlg->remote_tag == NULL)	/* tag in response BUT no tag in dialog */
+  if (dlg->remote_tag == NULL)  /* tag in response BUT no tag in dialog */
     {
       OSIP_TRACE (osip_trace
-		  (__FILE__, __LINE__, OSIP_WARNING, NULL,
-		   "Remote UA is not compliant: missing a tag in To feilds!\n"));
+                  (__FILE__, __LINE__, OSIP_WARNING, NULL,
+                   "Remote UA is not compliant: missing a tag in To feilds!\n"));
       if (0 ==
-	  osip_from_compare ((osip_from_t *) dlg->remote_uri,
-			     (osip_from_t *) request->from)
-	  && 0 == osip_from_compare (dlg->local_uri, request->to))
-	return 0;
+          osip_from_compare ((osip_from_t *) dlg->remote_uri,
+                             (osip_from_t *) request->from)
+          && 0 == osip_from_compare (dlg->local_uri, request->to))
+        return 0;
       return -1;
     }
   /* we don't have to compare
@@ -335,7 +331,7 @@ osip_dialog_init_as_uac (osip_dialog_t ** dialog, osip_message_t * response)
   (*dialog)->type = CALLER;
   if (MSG_IS_STATUS_2XX (response))
     (*dialog)->state = DIALOG_CONFIRMED;
-  else				/* 1XX */
+  else                          /* 1XX */
     (*dialog)->state = DIALOG_EARLY;
 
   i = osip_call_id_to_str (response->call_id, &((*dialog)->call_id));
@@ -351,11 +347,10 @@ osip_dialog_init_as_uac (osip_dialog_t ** dialog, osip_message_t * response)
   if (i != 0)
     {
       OSIP_TRACE (osip_trace
-		  (__FILE__, __LINE__, OSIP_WARNING, NULL,
-		   "Remote UA is not compliant: missing a tag in response!\n"));
+                  (__FILE__, __LINE__, OSIP_WARNING, NULL,
+                   "Remote UA is not compliant: missing a tag in response!\n"));
       (*dialog)->remote_tag = NULL;
-    }
-  else
+  } else
     (*dialog)->remote_tag = osip_strdup (tag->gvalue);
 
   (*dialog)->route_set = (osip_list_t *) osip_malloc (sizeof (osip_list_t));
@@ -367,12 +362,15 @@ osip_dialog_init_as_uac (osip_dialog_t ** dialog, osip_message_t * response)
       osip_record_route_t *rr;
       osip_record_route_t *rr2;
 
-      rr =
-	(osip_record_route_t *) osip_list_get (response->record_routes, pos);
+      rr = (osip_record_route_t *) osip_list_get (response->record_routes, pos);
       i = osip_record_route_clone (rr, &rr2);
       if (i != 0)
-	goto diau_error_2;
+        goto diau_error_2;
+#ifdef OSIP_FUTURE_FIX_2_3
+      osip_list_add ((*dialog)->route_set, rr2, 0);
+#else
       osip_list_add ((*dialog)->route_set, rr2, -1);
+#endif
       pos++;
     }
 
@@ -392,20 +390,19 @@ osip_dialog_init_as_uac (osip_dialog_t ** dialog, osip_message_t * response)
 
     if (!osip_list_eol (response->contacts, 0))
       {
-	contact = osip_list_get (response->contacts, 0);
-	i = osip_contact_clone (contact, &((*dialog)->remote_contact_uri));
-	if (i != 0)
-	  goto diau_error_5;
-      }
-    else
+        contact = osip_list_get (response->contacts, 0);
+        i = osip_contact_clone (contact, &((*dialog)->remote_contact_uri));
+        if (i != 0)
+          goto diau_error_5;
+    } else
       {
-	(*dialog)->remote_contact_uri = NULL;
-	OSIP_TRACE (osip_trace
-		    (__FILE__, __LINE__, OSIP_WARNING, NULL,
-		     "Remote UA is not compliant: missing a contact in response!\n"));
+        (*dialog)->remote_contact_uri = NULL;
+        OSIP_TRACE (osip_trace
+                    (__FILE__, __LINE__, OSIP_WARNING, NULL,
+                     "Remote UA is not compliant: missing a contact in response!\n"));
       }
   }
-  (*dialog)->secure = -1;	/* non secure */
+  (*dialog)->secure = -1;       /* non secure */
 
   return 0;
 
@@ -416,25 +413,25 @@ diau_error_4:
 diau_error_3:
 diau_error_2:
   osip_list_special_free ((*dialog)->route_set,
-			  (void *(*)(void *)) &osip_record_route_free);
+                          (void *(*)(void *)) &osip_record_route_free);
   osip_free ((*dialog)->remote_tag);
   osip_free ((*dialog)->local_tag);
 diau_error_1:
   osip_free ((*dialog)->call_id);
 diau_error_0:
   OSIP_TRACE (osip_trace
-	      (__FILE__, __LINE__, OSIP_ERROR, NULL,
-	       "Could not establish dialog!\n"));
+              (__FILE__, __LINE__, OSIP_ERROR, NULL,
+               "Could not establish dialog!\n"));
   osip_free (*dialog);
   *dialog = NULL;
   return -1;
 }
 
-#if 1				/* SIPIT13 */
+#if 1                           /* SIPIT13 */
 int
 osip_dialog_init_as_uac_with_remote_request (osip_dialog_t ** dialog,
-					     osip_message_t * next_request,
-					     int local_cseq)
+                                             osip_message_t * next_request,
+                                             int local_cseq)
 {
   int i;
   osip_generic_param_t *tag;
@@ -467,17 +464,16 @@ osip_dialog_init_as_uac_with_remote_request (osip_dialog_t ** dialog,
   if (i != 0)
     {
       OSIP_TRACE (osip_trace
-		  (__FILE__, __LINE__, OSIP_WARNING, NULL,
-		   "Remote UA is not compliant: missing a tag in next request!\n"));
+                  (__FILE__, __LINE__, OSIP_WARNING, NULL,
+                   "Remote UA is not compliant: missing a tag in next request!\n"));
       (*dialog)->remote_tag = NULL;
-    }
-  else
+  } else
     (*dialog)->remote_tag = osip_strdup (tag->gvalue);
 
   (*dialog)->route_set = (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   osip_list_init ((*dialog)->route_set);
 
-  (*dialog)->local_cseq = local_cseq;	/* -1 osip_atoi (xxx->cseq->number); */
+  (*dialog)->local_cseq = local_cseq;   /* -1 osip_atoi (xxx->cseq->number); */
   (*dialog)->remote_cseq = osip_atoi (next_request->cseq->number);
 
   i = osip_to_clone (next_request->from, &((*dialog)->remote_uri));
@@ -493,21 +489,20 @@ osip_dialog_init_as_uac_with_remote_request (osip_dialog_t ** dialog,
 
     if (!osip_list_eol (next_request->contacts, 0))
       {
-	contact = osip_list_get (next_request->contacts, 0);
-	i = osip_contact_clone (contact, &((*dialog)->remote_contact_uri));
-	if (i != 0)
-	  goto diau_error_5;
-      }
-    else
+        contact = osip_list_get (next_request->contacts, 0);
+        i = osip_contact_clone (contact, &((*dialog)->remote_contact_uri));
+        if (i != 0)
+          goto diau_error_5;
+    } else
       {
-	(*dialog)->remote_contact_uri = NULL;
-	OSIP_TRACE (osip_trace
-		    (__FILE__, __LINE__, OSIP_WARNING, NULL,
-		     "Remote UA is not compliant? missing a contact in response!\n"));
+        (*dialog)->remote_contact_uri = NULL;
+        OSIP_TRACE (osip_trace
+                    (__FILE__, __LINE__, OSIP_WARNING, NULL,
+                     "Remote UA is not compliant? missing a contact in response!\n"));
       }
   }
 
-  (*dialog)->secure = -1;	/* non secure */
+  (*dialog)->secure = -1;       /* non secure */
 
   return 0;
 
@@ -522,8 +517,8 @@ diau_error_1:
   osip_free ((*dialog)->call_id);
 diau_error_0:
   OSIP_TRACE (osip_trace
-	      (__FILE__, __LINE__, OSIP_ERROR, NULL,
-	       "Could not establish dialog!\n"));
+              (__FILE__, __LINE__, OSIP_ERROR, NULL,
+               "Could not establish dialog!\n"));
   osip_free (*dialog);
   *dialog = NULL;
   return -1;
@@ -532,7 +527,7 @@ diau_error_0:
 
 int
 osip_dialog_init_as_uas (osip_dialog_t ** dialog, osip_message_t * invite,
-			 osip_message_t * response)
+                         osip_message_t * response)
 {
   int i;
   int pos;
@@ -548,7 +543,7 @@ osip_dialog_init_as_uas (osip_dialog_t ** dialog, osip_message_t * invite,
   (*dialog)->type = CALLEE;
   if (MSG_IS_STATUS_2XX (response))
     (*dialog)->state = DIALOG_CONFIRMED;
-  else				/* 1XX */
+  else                          /* 1XX */
     (*dialog)->state = DIALOG_EARLY;
 
   i = osip_call_id_to_str (response->call_id, &((*dialog)->call_id));
@@ -564,11 +559,10 @@ osip_dialog_init_as_uas (osip_dialog_t ** dialog, osip_message_t * invite,
   if (i != 0)
     {
       OSIP_TRACE (osip_trace
-		  (__FILE__, __LINE__, OSIP_WARNING, NULL,
-		   "Remote UA is not compliant: missing a tag in response!\n"));
+                  (__FILE__, __LINE__, OSIP_WARNING, NULL,
+                   "Remote UA is not compliant: missing a tag in response!\n"));
       (*dialog)->remote_tag = NULL;
-    }
-  else
+  } else
     (*dialog)->remote_tag = osip_strdup (tag->gvalue);
 
   (*dialog)->route_set = (osip_list_t *) osip_malloc (sizeof (osip_list_t));
@@ -580,11 +574,10 @@ osip_dialog_init_as_uas (osip_dialog_t ** dialog, osip_message_t * invite,
       osip_record_route_t *rr;
       osip_record_route_t *rr2;
 
-      rr =
-	(osip_record_route_t *) osip_list_get (response->record_routes, pos);
+      rr = (osip_record_route_t *) osip_list_get (response->record_routes, pos);
       i = osip_record_route_clone (rr, &rr2);
       if (i != 0)
-	goto diau_error_2;
+        goto diau_error_2;
       osip_list_add ((*dialog)->route_set, rr2, -1);
       pos++;
     }
@@ -608,20 +601,19 @@ osip_dialog_init_as_uas (osip_dialog_t ** dialog, osip_message_t * invite,
 
     if (!osip_list_eol (invite->contacts, 0))
       {
-	contact = osip_list_get (invite->contacts, 0);
-	i = osip_contact_clone (contact, &((*dialog)->remote_contact_uri));
-	if (i != 0)
-	  goto diau_error_5;
-      }
-    else
+        contact = osip_list_get (invite->contacts, 0);
+        i = osip_contact_clone (contact, &((*dialog)->remote_contact_uri));
+        if (i != 0)
+          goto diau_error_5;
+    } else
       {
-	(*dialog)->remote_contact_uri = NULL;
-	OSIP_TRACE (osip_trace
-		    (__FILE__, __LINE__, OSIP_WARNING, NULL,
-		     "Remote UA is not compliant: missing a contact in response!\n"));
+        (*dialog)->remote_contact_uri = NULL;
+        OSIP_TRACE (osip_trace
+                    (__FILE__, __LINE__, OSIP_WARNING, NULL,
+                     "Remote UA is not compliant: missing a contact in response!\n"));
       }
   }
-  (*dialog)->secure = -1;	/* non secure */
+  (*dialog)->secure = -1;       /* non secure */
 
   return 0;
 
@@ -632,15 +624,15 @@ diau_error_4:
 diau_error_3:
 diau_error_2:
   osip_list_special_free ((*dialog)->route_set,
-			  (void *(*)(void *)) &osip_record_route_free);
+                          (void *(*)(void *)) &osip_record_route_free);
   osip_free ((*dialog)->remote_tag);
   osip_free ((*dialog)->local_tag);
 diau_error_1:
   osip_free ((*dialog)->call_id);
 diau_error_0:
   OSIP_TRACE (osip_trace
-	      (__FILE__, __LINE__, OSIP_ERROR, NULL,
-	       "Could not establish dialog!\n"));
+              (__FILE__, __LINE__, OSIP_ERROR, NULL,
+               "Could not establish dialog!\n"));
   osip_free (*dialog);
   *dialog = NULL;
   return -1;
@@ -655,7 +647,7 @@ osip_dialog_free (osip_dialog_t * dialog)
   osip_from_free (dialog->local_uri);
   osip_to_free (dialog->remote_uri);
   osip_list_special_free (dialog->route_set,
-			  (void *(*)(void *)) &osip_record_route_free);
+                          (void *(*)(void *)) &osip_record_route_free);
   osip_free (dialog->remote_tag);
   osip_free (dialog->local_tag);
   osip_free (dialog->call_id);
