@@ -54,13 +54,13 @@ osip_message_set_accept_encoding (osip_message_t * sip, const char *hvalue)
 
 int
 osip_message_get_accept_encoding (const osip_message_t * sip, int pos,
-				  osip_accept_encoding_t ** dest)
+                                  osip_accept_encoding_t ** dest)
 {
   osip_accept_encoding_t *accept_encoding;
 
   *dest = NULL;
   if (osip_list_size (sip->accept_encodings) <= pos)
-    return -1;			/* does not exist */
+    return -1;                  /* does not exist */
   accept_encoding =
     (osip_accept_encoding_t *) osip_list_get (sip->accept_encodings, pos);
   *dest = accept_encoding;
@@ -91,7 +91,7 @@ osip_accept_encoding_init (osip_accept_encoding_t ** accept_encoding)
 
 int
 osip_accept_encoding_parse (osip_accept_encoding_t * accept_encoding,
-			    const char *hvalue)
+                            const char *hvalue)
 {
   const char *osip_accept_encoding_params;
 
@@ -100,10 +100,9 @@ osip_accept_encoding_parse (osip_accept_encoding_t * accept_encoding,
   if (osip_accept_encoding_params != NULL)
     {
       if (__osip_generic_param_parseall (accept_encoding->gen_params,
-					 osip_accept_encoding_params) == -1)
-	return -1;
-    }
-  else
+                                         osip_accept_encoding_params) == -1)
+        return -1;
+  } else
     osip_accept_encoding_params = hvalue + strlen (hvalue);
 
   if (osip_accept_encoding_params - hvalue + 1 < 2)
@@ -112,9 +111,8 @@ osip_accept_encoding_parse (osip_accept_encoding_t * accept_encoding,
     (char *) osip_malloc (osip_accept_encoding_params - hvalue + 1);
   if (accept_encoding->element == NULL)
     return -1;
-  osip_strncpy (accept_encoding->element, hvalue,
-		osip_accept_encoding_params - hvalue);
-  osip_clrspace (accept_encoding->element);
+  osip_clrncpy (accept_encoding->element, hvalue,
+                osip_accept_encoding_params - hvalue);
 
   return 0;
 }
@@ -124,7 +122,7 @@ osip_accept_encoding_parse (osip_accept_encoding_t * accept_encoding,
 /* returns null on error. */
 int
 osip_accept_encoding_to_str (const osip_accept_encoding_t * accept_encoding,
-			     char **dest)
+                             char **dest)
 {
   char *buf;
   char *tmp;
@@ -147,22 +145,22 @@ osip_accept_encoding_to_str (const osip_accept_encoding_t * accept_encoding,
 
     while (!osip_list_eol (accept_encoding->gen_params, pos))
       {
-	u_param =
-	  (osip_generic_param_t *) osip_list_get (accept_encoding->gen_params,
-						  pos);
-	if (u_param->gvalue == NULL)
-	  plen = strlen (u_param->gname) + 2;
-	else
-	  plen = strlen (u_param->gname) + strlen (u_param->gvalue) + 3;
-	len = len + plen;
-	buf = (char *) osip_realloc (buf, len);
-	tmp = buf;
-	tmp = tmp + strlen (tmp);
-	if (u_param->gvalue == NULL)
-	  sprintf (tmp, ";%s", u_param->gname);
-	else
-	  sprintf (tmp, ";%s=%s", u_param->gname, u_param->gvalue);
-	pos++;
+        u_param =
+          (osip_generic_param_t *) osip_list_get (accept_encoding->gen_params,
+                                                  pos);
+        if (u_param->gvalue == NULL)
+          plen = strlen (u_param->gname) + 2;
+        else
+          plen = strlen (u_param->gname) + strlen (u_param->gvalue) + 3;
+        len = len + plen;
+        buf = (char *) osip_realloc (buf, len);
+        tmp = buf;
+        tmp = tmp + strlen (tmp);
+        if (u_param->gvalue == NULL)
+          sprintf (tmp, ";%s", u_param->gname);
+        else
+          sprintf (tmp, ";%s=%s", u_param->gname, u_param->gvalue);
+        pos++;
       }
   }
   *dest = buf;
@@ -187,7 +185,7 @@ osip_accept_encoding_free (osip_accept_encoding_t * accept_encoding)
 
 int
 osip_accept_encoding_clone (const osip_accept_encoding_t * ctt,
-			    osip_accept_encoding_t ** dest)
+                            osip_accept_encoding_t ** dest)
 {
   int i;
   osip_accept_encoding_t *ct;
@@ -199,7 +197,7 @@ osip_accept_encoding_clone (const osip_accept_encoding_t * ctt,
     return -1;
 
   i = osip_accept_encoding_init (&ct);
-  if (i != 0)			/* allocation failed */
+  if (i != 0)                   /* allocation failed */
     return -1;
   ct->element = osip_strdup (ctt->element);
   if (ctt->element != NULL && ct->element == NULL)
@@ -214,16 +212,15 @@ osip_accept_encoding_clone (const osip_accept_encoding_t * ctt,
 
     while (!osip_list_eol (ctt->gen_params, pos))
       {
-	u_param =
-	  (osip_generic_param_t *) osip_list_get (ctt->gen_params, pos);
-	i = osip_generic_param_clone (u_param, &dest_param);
-	if (i != 0)
-	  {
-	    osip_accept_encoding_free (ct);
-	    return -1;
-	  }
-	osip_list_add (ct->gen_params, dest_param, -1);
-	pos++;
+        u_param = (osip_generic_param_t *) osip_list_get (ctt->gen_params, pos);
+        i = osip_generic_param_clone (u_param, &dest_param);
+        if (i != 0)
+          {
+            osip_accept_encoding_free (ct);
+            return -1;
+          }
+        osip_list_add (ct->gen_params, dest_param, -1);
+        pos++;
       }
   }
   *dest = ct;
