@@ -29,7 +29,9 @@
 int
 osip_authentication_info_init (osip_authentication_info_t ** dest)
 {
-  *dest = (osip_authentication_info_t *) osip_malloc (sizeof (osip_authentication_info_t));
+  *dest =
+    (osip_authentication_info_t *)
+    osip_malloc (sizeof (osip_authentication_info_t));
   if (*dest == NULL)
     return -1;
   (*dest)->nextnonce = NULL;
@@ -50,7 +52,7 @@ osip_message_set_authentication_info (osip_message_t * sip, const char *hvalue)
   osip_authentication_info_t *authentication_info;
   int i;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   if (sip == NULL || sip->authentication_infos == NULL)
@@ -79,7 +81,8 @@ osip_message_set_authentication_info (osip_message_t * sip, const char *hvalue)
    verify many situations (extra SP....)
 */
 int
-osip_authentication_info_parse (osip_authentication_info_t * ainfo, const char *hvalue)
+osip_authentication_info_parse (osip_authentication_info_t * ainfo,
+                                const char *hvalue)
 {
   const char *space;
   const char *next = NULL;
@@ -90,82 +93,82 @@ osip_authentication_info_parse (osip_authentication_info_t * ainfo, const char *
     {
       int parse_ok = 0;
 
-      if (__osip_quoted_string_set ("nextnonce", space, &(ainfo->nextnonce), &next))
-	return -1;
+      if (__osip_quoted_string_set
+          ("nextnonce", space, &(ainfo->nextnonce), &next))
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
+        {
+          space = next;
+          parse_ok++;
+        }
       if (__osip_quoted_string_set ("cnonce", space, &(ainfo->cnonce), &next))
-	return -1;
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
+        {
+          space = next;
+          parse_ok++;
+        }
       if (__osip_quoted_string_set ("rspauth", space, &(ainfo->rspauth), &next))
-	return -1;
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
+        {
+          space = next;
+          parse_ok++;
+        }
       if (__osip_token_set ("nc", space, &(ainfo->nonce_count), &next))
-	return -1;
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
+        {
+          space = next;
+          parse_ok++;
+        }
       if (__osip_token_set ("qop", space, &(ainfo->qop_options), &next))
-	return -1;
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
+        {
+          space = next;
+          parse_ok++;
+        }
       if (0 == parse_ok)
-	{
-	  char *quote1, *quote2, *tmp;
+        {
+          char *quote1, *quote2, *tmp;
 
-	  /* CAUTION */
-	  /* parameter not understood!!! I'm too lazy to handle IT */
-	  /* let's simply bypass it */
-	  if (strlen (space) < 1)
-	    return 0;
-	  tmp = strchr (space + 1, ',');
-	  if (tmp == NULL)	/* it was the last header */
-	    return 0;
-	  quote1 = __osip_quote_find (space);
-	  if ((quote1 != NULL) && (quote1 < tmp))	/* this may be a quoted string! */
-	    {
-	      quote2 = __osip_quote_find (quote1 + 1);
-	      if (quote2 == NULL)
-		return -1;	/* bad header format... */
-	      if (tmp < quote2)	/* the comma is inside the quotes! */
-		space = strchr (quote2, ',');
-	      else
-		space = tmp;
-	      if (space == NULL)	/* it was the last header */
-		return 0;
-	    }
-	  else
-	    space = tmp;
-	  /* continue parsing... */
-	}
+          /* CAUTION */
+          /* parameter not understood!!! I'm too lazy to handle IT */
+          /* let's simply bypass it */
+          if (strlen (space) < 1)
+            return 0;
+          tmp = strchr (space + 1, ',');
+          if (tmp == NULL)      /* it was the last header */
+            return 0;
+          quote1 = __osip_quote_find (space);
+          if ((quote1 != NULL) && (quote1 < tmp))       /* this may be a quoted string! */
+            {
+              quote2 = __osip_quote_find (quote1 + 1);
+              if (quote2 == NULL)
+                return -1;      /* bad header format... */
+              if (tmp < quote2) /* the comma is inside the quotes! */
+                space = strchr (quote2, ',');
+              else
+                space = tmp;
+              if (space == NULL)        /* it was the last header */
+                return 0;
+          } else
+            space = tmp;
+          /* continue parsing... */
+        }
     }
-  return 0;			/* ok */
+  return 0;                     /* ok */
 }
 
 /* returns the authentication_info header.            */
@@ -173,13 +176,13 @@ osip_authentication_info_parse (osip_authentication_info_t * ainfo, const char *
 /* returns null on error. */
 int
 osip_message_get_authentication_info (const osip_message_t * sip, int pos,
-			 osip_authentication_info_t ** dest)
+                                      osip_authentication_info_t ** dest)
 {
   osip_authentication_info_t *authentication_info;
 
   *dest = NULL;
   if (osip_list_size (sip->authentication_infos) <= pos)
-    return -1;			/* does not exist */
+    return -1;                  /* does not exist */
 
   authentication_info =
     (osip_authentication_info_t *) osip_list_get (sip->authentication_infos, pos);
@@ -189,64 +192,71 @@ osip_message_get_authentication_info (const osip_message_t * sip, int pos,
 }
 
 char *
-osip_authentication_info_get_nextnonce (osip_authentication_info_t * authentication_info)
+osip_authentication_info_get_nextnonce (osip_authentication_info_t *
+                                        authentication_info)
 {
   return authentication_info->nextnonce;
 }
 
 void
-osip_authentication_info_set_nextnonce (osip_authentication_info_t * authentication_info,
-			       char *nextnonce)
+osip_authentication_info_set_nextnonce (osip_authentication_info_t *
+                                        authentication_info, char *nextnonce)
 {
   authentication_info->nextnonce = (char *) nextnonce;
 }
 
 char *
-osip_authentication_info_get_cnonce (osip_authentication_info_t * authentication_info)
+osip_authentication_info_get_cnonce (osip_authentication_info_t *
+                                     authentication_info)
 {
   return authentication_info->cnonce;
 }
 
 void
-osip_authentication_info_set_cnonce (osip_authentication_info_t * authentication_info, char *cnonce)
+osip_authentication_info_set_cnonce (osip_authentication_info_t *
+                                     authentication_info, char *cnonce)
 {
   authentication_info->cnonce = (char *) cnonce;
 }
 
 char *
-osip_authentication_info_get_rspauth (osip_authentication_info_t * authentication_info)
+osip_authentication_info_get_rspauth (osip_authentication_info_t *
+                                      authentication_info)
 {
   return authentication_info->rspauth;
 }
 
 void
-osip_authentication_info_set_rspauth (osip_authentication_info_t * authentication_info,
-			    char *rspauth)
+osip_authentication_info_set_rspauth (osip_authentication_info_t *
+                                      authentication_info, char *rspauth)
 {
   authentication_info->rspauth = (char *) rspauth;
 }
 
 char *
-osip_authentication_info_get_nonce_count (osip_authentication_info_t * authentication_info)
+osip_authentication_info_get_nonce_count (osip_authentication_info_t *
+                                          authentication_info)
 {
   return authentication_info->nonce_count;
 }
 
 void
-osip_authentication_info_set_nonce_count (osip_authentication_info_t * authentication_info, char *nonce_count)
+osip_authentication_info_set_nonce_count (osip_authentication_info_t *
+                                          authentication_info, char *nonce_count)
 {
   authentication_info->nonce_count = (char *) nonce_count;
 }
 
 char *
-osip_authentication_info_get_qop_options (osip_authentication_info_t * authentication_info)
+osip_authentication_info_get_qop_options (osip_authentication_info_t *
+                                          authentication_info)
 {
   return authentication_info->qop_options;
 }
 
 void
-osip_authentication_info_set_qop_options (osip_authentication_info_t * authentication_info,
-				 char *qop_options)
+osip_authentication_info_set_qop_options (osip_authentication_info_t *
+                                          authentication_info, char *qop_options)
 {
   authentication_info->qop_options = (char *) qop_options;
 }
@@ -257,7 +267,8 @@ osip_authentication_info_set_qop_options (osip_authentication_info_t * authentic
 /* INPUT : osip_authentication_info_t *authentication_info | authentication_info header.  */
 /* returns null on error. */
 int
-osip_authentication_info_to_str (const osip_authentication_info_t * ainfo, char **dest)
+osip_authentication_info_to_str (const osip_authentication_info_t * ainfo,
+                                 char **dest)
 {
   size_t len;
   char *tmp;
@@ -288,58 +299,44 @@ osip_authentication_info_to_str (const osip_authentication_info_t * ainfo, char
 
   if (ainfo->qop_options != NULL)
     {
-      osip_strncpy (tmp, "qop=", 4);
-      tmp = tmp + 4;
-      osip_strncpy (tmp, ainfo->qop_options, strlen (ainfo->qop_options));
-      tmp = tmp + strlen (tmp);
+      tmp = osip_strn_append (tmp, "qop=", 4);
+      tmp = osip_str_append (tmp, ainfo->qop_options);
     }
   if (ainfo->nextnonce != NULL)
     {
-      if (tmp!=*dest)
-	{
-	  osip_strncpy (tmp, ", ", 2);
-	  tmp = tmp + 2;
-	}      
-      osip_strncpy (tmp, "nextnonce=", 10);
-      tmp = tmp + 10;
-      osip_strncpy (tmp, ainfo->nextnonce, strlen (ainfo->nextnonce));
-      tmp = tmp + strlen (tmp);
+      if (tmp != *dest)
+        {
+          tmp = osip_strn_append (tmp, ", ", 2);
+        }
+      tmp = osip_strn_append (tmp, "nextnonce=", 10);
+      tmp = osip_str_append (tmp, ainfo->nextnonce);
     }
   if (ainfo->rspauth != NULL)
     {
-      if (tmp!=*dest)
-	{
-	  osip_strncpy (tmp, ", ", 2);
-	  tmp = tmp + 2;
-	}      
-      osip_strncpy (tmp, "rspauth=", 8);
-      tmp = tmp + 8;
-      osip_strncpy (tmp, ainfo->rspauth, strlen (ainfo->rspauth));
-      tmp = tmp + strlen (tmp);
+      if (tmp != *dest)
+        {
+          tmp = osip_strn_append (tmp, ", ", 2);
+        }
+      tmp = osip_strn_append (tmp, "rspauth=", 8);
+      tmp = osip_str_append (tmp, ainfo->rspauth);
     }
   if (ainfo->cnonce != NULL)
     {
-      if (tmp!=*dest)
-	{
-	  osip_strncpy (tmp, ", ", 2);
-	  tmp = tmp + 2;
-	}      
-      osip_strncpy (tmp, "cnonce=", 7);
-      tmp = tmp + 7;
-      osip_strncpy (tmp, ainfo->cnonce, strlen (ainfo->cnonce));
-      tmp = tmp + strlen (tmp);
+      if (tmp != *dest)
+        {
+          tmp = osip_strn_append (tmp, ", ", 2);
+        }
+      tmp = osip_strn_append (tmp, "cnonce=", 7);
+      tmp = osip_str_append (tmp, ainfo->cnonce);
     }
   if (ainfo->nonce_count != NULL)
     {
-      if (tmp!=*dest)
-	{
-	  osip_strncpy (tmp, ", ", 2);
-	  tmp = tmp + 2;
-	}      
-      osip_strncpy (tmp, "nc=", 3);
-      tmp = tmp + 3;
-      osip_strncpy (tmp, ainfo->nonce_count, strlen (ainfo->nonce_count));
-      tmp = tmp + strlen (tmp);
+      if (tmp != *dest)
+        {
+          tmp = osip_strn_append (tmp, ", ", 2);
+        }
+      tmp = osip_strn_append (tmp, "nc=", 3);
+      tmp = osip_str_append (tmp, ainfo->nonce_count);
     }
 
   return 0;
@@ -363,7 +360,7 @@ osip_authentication_info_free (osip_authentication_info_t * authentication_info)
 
 int
 osip_authentication_info_clone (const osip_authentication_info_t * ainfo,
-			osip_authentication_info_t ** dest)
+                                osip_authentication_info_t ** dest)
 {
   int i;
   osip_authentication_info_t *wa;
@@ -373,7 +370,7 @@ osip_authentication_info_clone (const osip_authentication_info_t * ainfo,
     return -1;
 
   i = osip_authentication_info_init (&wa);
-  if (i == -1)			/* allocation failed */
+  if (i == -1)                  /* allocation failed */
     return -1;
   if (ainfo->nextnonce != NULL)
     wa->nextnonce = osip_strdup (ainfo->nextnonce);
