@@ -27,8 +27,8 @@
 #include "parser.h"
 
 static int osip_body_parse_header (osip_body_t * body,
-				   const char *start_of_osip_body_header,
-				   const char **next_body);
+                                   const char *start_of_osip_body_header,
+                                   const char **next_body);
 
 int
 osip_body_init (osip_body_t ** body)
@@ -84,23 +84,24 @@ osip_body_clone (const osip_body_t * body, osip_body_t ** dest)
   int i;
   osip_body_t *copy;
 
-  if (body == NULL || body->length<=0)
+  if (body == NULL || body->length <= 0)
     return -1;
 
   i = osip_body_init (&copy);
   if (i != 0)
     return -1;
 
-  
-  copy->body = (char*)osip_malloc(body->length+1);
+
+  copy->body = (char *) osip_malloc (body->length + 2);
   copy->length = body->length;
-  memcpy(copy->body,body->body,body->length);
+  memcpy (copy->body, body->body, body->length);
+  copy->body[body->length] = '\0';
 
   if (body->content_type != NULL)
     {
       i = osip_content_type_clone (body->content_type, &(copy->content_type));
       if (i != 0)
-	goto bc_error1;
+        goto bc_error1;
     }
 
   {
@@ -110,12 +111,12 @@ osip_body_clone (const osip_body_t * body, osip_body_t ** dest)
     pos = 0;
     while (!osip_list_eol (body->headers, pos))
       {
-	header = (osip_header_t *) osip_list_get (body->headers, pos);
-	i = osip_header_clone (header, &header2);
-	if (i != 0)
-	  goto bc_error1;
-	osip_list_add (copy->headers, header2, -1);	/* insert as last element */
-	pos++;
+        header = (osip_header_t *) osip_list_get (body->headers, pos);
+        i = osip_header_clone (header, &header2);
+        if (i != 0)
+          goto bc_error1;
+        osip_list_add (copy->headers, header2, -1);     /* insert as last element */
+        pos++;
       }
   }
 
@@ -132,14 +133,13 @@ bc_error1:
 /* OUTPUT: osip_body_t *body | structure to save results. */
 /* returns -1 on error. */
 int
-osip_message_get_body (const osip_message_t * sip, int pos,
-		       osip_body_t ** dest)
+osip_message_get_body (const osip_message_t * sip, int pos, osip_body_t ** dest)
 {
   osip_body_t *body;
 
   *dest = NULL;
   if (osip_list_size (sip->bodies) <= pos)
-    return -1;			/* does not exist */
+    return -1;                  /* does not exist */
   body = (osip_body_t *) osip_list_get (sip->bodies, pos);
   *dest = body;
   return pos;
@@ -169,8 +169,7 @@ osip_body_set_contenttype (osip_body_t * body, const char *hvalue)
 }
 
 int
-osip_body_set_header (osip_body_t * body, const char *hname,
-		      const char *hvalue)
+osip_body_set_header (osip_body_t * body, const char *hname, const char *hvalue)
 {
   osip_header_t *h;
   int i;
@@ -219,8 +218,8 @@ osip_message_set_body_mime (osip_message_t * sip, const char *buf, size_t length
 
 static int
 osip_body_parse_header (osip_body_t * body,
-			const char *start_of_osip_body_header,
-			const char **next_body)
+                        const char *start_of_osip_body_header,
+                        const char **next_body)
 {
   const char *start_of_line;
   const char *end_of_line;
@@ -235,50 +234,47 @@ osip_body_parse_header (osip_body_t * body,
     {
       i = __osip_find_next_crlf (start_of_line, &end_of_line);
       if (i == -1)
-	return -1;		/* error case: no end of body found */
+        return -1;              /* error case: no end of body found */
 
       /* find the headere name */
       colon_index = strchr (start_of_line, ':');
       if (colon_index == NULL)
-	return -1;		/* this is also an error case */
+        return -1;              /* this is also an error case */
 
       if (colon_index - start_of_line + 1 < 2)
-	return -1;
+        return -1;
       hname = (char *) osip_malloc (colon_index - start_of_line + 1);
       if (hname == NULL)
-	return -1;
-      osip_strncpy (hname, start_of_line, colon_index - start_of_line);
-      osip_clrspace (hname);
+        return -1;
+      osip_clrncpy (hname, start_of_line, colon_index - start_of_line);
 
       if ((end_of_line - 2) - colon_index < 2)
-	return -1;
+        return -1;
       hvalue = (char *) osip_malloc ((end_of_line - 2) - colon_index);
       if (hvalue == NULL)
-	{
-	  osip_free (hname);
-	  return -1;
-	}
-      osip_strncpy (hvalue, colon_index + 1,
-		    (end_of_line - 2) - colon_index - 1);
-      osip_clrspace (hvalue);
+        {
+          osip_free (hname);
+          return -1;
+        }
+      osip_clrncpy (hvalue, colon_index + 1, (end_of_line - 2) - colon_index - 1);
 
       /* really store the header in the sip structure */
       if (osip_strncasecmp (hname, "content-type", 12) == 0)
-	i = osip_body_set_contenttype (body, hvalue);
+        i = osip_body_set_contenttype (body, hvalue);
       else
-	i = osip_body_set_header (body, hname, hvalue);
+        i = osip_body_set_header (body, hname, hvalue);
       osip_free (hname);
       osip_free (hvalue);
       if (i == -1)
-	return -1;
+        return -1;
 
       if (strncmp (end_of_line, CRLF, 2) == 0
-	  || strncmp (end_of_line, "\n", 1) == 0
-	  || strncmp (end_of_line, "\r", 1) == 0)
-	{
-	  *next_body = end_of_line;
-	  return 0;
-	}
+          || strncmp (end_of_line, "\n", 1) == 0
+          || strncmp (end_of_line, "\r", 1) == 0)
+        {
+          *next_body = end_of_line;
+          return 0;
+        }
       start_of_line = end_of_line;
     }
 }
@@ -296,8 +292,8 @@ osip_body_parse (osip_body_t * body, const char *start_of_body, size_t length)
   body->body = (char *) osip_malloc (length + 1);
   if (body->body == NULL)
     return -1;
-  memcpy(body->body,start_of_body,length);
-  body->body[length]='\0';
+  memcpy (body->body, start_of_body, length);
+  body->body[length] = '\0';
   body->length = length;
   return 0;
 }
@@ -320,7 +316,7 @@ osip_body_parse_mime (osip_body_t * body, const char *start_of_body, size_t leng
 
   i =
     osip_body_parse_header (body, start_of_osip_body_header,
-			    &end_of_osip_body_header);
+                            &end_of_osip_body_header);
   if (i == -1)
     return -1;
 
@@ -331,22 +327,21 @@ osip_body_parse_mime (osip_body_t * body, const char *start_of_body, size_t leng
   else
     {
       if ((strncmp (start_of_osip_body_header, "\n", 1) == 0)
-	  || (strncmp (start_of_osip_body_header, "\r", 1) == 0))
-	start_of_osip_body_header = start_of_osip_body_header + 1;
+          || (strncmp (start_of_osip_body_header, "\r", 1) == 0))
+        start_of_osip_body_header = start_of_osip_body_header + 1;
       else
-	return -1;		/* message does not end with CRLFCRLF, CRCR or LFLF */
+        return -1;              /* message does not end with CRLFCRLF, CRCR or LFLF */
     }
 
   end_of_osip_body_header = start_of_body + length;
-  if (end_of_osip_body_header-start_of_osip_body_header<=0)
+  if (end_of_osip_body_header - start_of_osip_body_header <= 0)
     return -1;
   body->body =
-    (char *) osip_malloc (end_of_osip_body_header -
-			  start_of_osip_body_header + 1);
+    (char *) osip_malloc (end_of_osip_body_header - start_of_osip_body_header + 1);
   if (body->body == NULL)
     return -1;
   memcpy (body->body, start_of_osip_body_header,
-	  end_of_osip_body_header - start_of_osip_body_header);
+          end_of_osip_body_header - start_of_osip_body_header);
   body->length = end_of_osip_body_header - start_of_osip_body_header;
 
   return 0;
@@ -357,7 +352,7 @@ osip_body_parse_mime (osip_body_t * body, const char *start_of_body, size_t leng
 /* INPUT : osip_body_t *body | body.  */
 /* returns null on error. */
 int
-osip_body_to_str (const osip_body_t * body, char **dest, size_t *str_length)
+osip_body_to_str (const osip_body_t * body, char **dest, size_t * str_length)
 {
   char *tmp_body;
   char *tmp;
@@ -377,37 +372,34 @@ osip_body_to_str (const osip_body_t * body, char **dest, size_t *str_length)
   if (body->length <= 0)
     return -1;
 
-  length = body->length + (osip_list_size (body->headers) * 40);
+  length = 15 + body->length + (osip_list_size (body->headers) * 40);
   tmp_body = (char *) osip_malloc (length);
   if (tmp_body == NULL)
     return -1;
-  ptr = tmp_body;		/* save the initial address of the string */
+  ptr = tmp_body;               /* save the initial address of the string */
 
   if (body->content_type != NULL)
     {
-      osip_strncpy (tmp_body, "content-type: ", 14);
-      tmp_body = tmp_body + strlen (tmp_body);
+      tmp_body = osip_strn_append (tmp_body, "content-type: ", 14);
       i = osip_content_type_to_str (body->content_type, &tmp);
       if (i == -1)
-	{
-	  osip_free (ptr);
-	  return -1;
-	}
+        {
+          osip_free (ptr);
+          return -1;
+        }
       if (length < tmp_body - ptr + strlen (tmp) + 4)
-	{
-	  size_t len;
+        {
+          size_t len;
 
-	  len = tmp_body - ptr;
-	  length = length + strlen (tmp) + 4;
-	  ptr = osip_realloc (ptr, length);
-	  tmp_body = ptr + len;
-	}
+          len = tmp_body - ptr;
+          length = length + strlen (tmp) + 4;
+          ptr = osip_realloc (ptr, length);
+          tmp_body = ptr + len;
+        }
 
-      osip_strncpy (tmp_body, tmp, strlen (tmp));
+      tmp_body = osip_str_append (tmp_body, tmp);
       osip_free (tmp);
-      tmp_body = tmp_body + strlen (tmp_body);
-      osip_strncpy (tmp_body, CRLF, 2);
-      tmp_body = tmp_body + 2;
+      tmp_body = osip_strn_append (tmp_body, CRLF, 2);
     }
 
   pos = 0;
@@ -418,31 +410,28 @@ osip_body_to_str (const osip_body_t * body, char **dest, size_t *str_length)
       header = (osip_header_t *) osip_list_get (body->headers, pos);
       i = osip_header_to_str (header, &tmp);
       if (i == -1)
-	{
-	  osip_free (ptr);
-	  return -1;
-	}
+        {
+          osip_free (ptr);
+          return -1;
+        }
       if (length < tmp_body - ptr + strlen (tmp) + 4)
-	{
-	  size_t len;
+        {
+          size_t len;
 
-	  len = tmp_body - ptr;
-	  length = length + strlen (tmp) + 4;
-	  ptr = osip_realloc (ptr, length);
-	  tmp_body = ptr + len;
-	}
-      osip_strncpy (tmp_body, tmp, strlen (tmp));
+          len = tmp_body - ptr;
+          length = length + strlen (tmp) + 4;
+          ptr = osip_realloc (ptr, length);
+          tmp_body = ptr + len;
+        }
+      tmp_body = osip_str_append (tmp_body, tmp);
       osip_free (tmp);
-      tmp_body = tmp_body + strlen (tmp_body);
-      osip_strncpy (tmp_body, CRLF, 2);
-      tmp_body = tmp_body + 2;
+      tmp_body = osip_strn_append (tmp_body, CRLF, 2);
       pos++;
     }
 
   if ((osip_list_size (body->headers) > 0) || (body->content_type != NULL))
     {
-      osip_strncpy (tmp_body, CRLF, 2);
-      tmp_body = tmp_body + 2;
+      tmp_body = osip_strn_append (tmp_body, CRLF, 2);
     }
   if (length < tmp_body - ptr + body->length + 4)
     {
@@ -453,12 +442,12 @@ osip_body_to_str (const osip_body_t * body, char **dest, size_t *str_length)
       ptr = osip_realloc (ptr, length);
       tmp_body = ptr + len;
     }
-  memcpy(tmp_body,body->body,body->length);
+  memcpy (tmp_body, body->body, body->length);
   tmp_body = tmp_body + body->length;
 
   /* end of this body */
-  if (str_length!=NULL)
-     *str_length = tmp_body - ptr;
+  if (str_length != NULL)
+    *str_length = tmp_body - ptr;
   *dest = ptr;
   return 0;
 
@@ -482,9 +471,9 @@ osip_body_free (osip_body_t * body)
 
     while (!osip_list_eol (body->headers, 0))
       {
-	header = (osip_header_t *) osip_list_get (body->headers, 0);
-	osip_list_remove (body->headers, 0);
-	osip_header_free (header);
+        header = (osip_header_t *) osip_list_get (body->headers, 0);
+        osip_list_remove (body->headers, 0);
+        osip_header_free (header);
       }
     osip_free (body->headers);
   }
