@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -27,8 +27,7 @@
 int
 osip_content_length_init (osip_content_length_t ** cl)
 {
-  *cl =
-    (osip_content_length_t *) osip_malloc (sizeof (osip_content_length_t));
+  *cl = (osip_content_length_t *) osip_malloc (sizeof (osip_content_length_t));
   if (*cl == NULL)
     return -1;
   (*cl)->value = NULL;
@@ -66,14 +65,19 @@ osip_message_set_content_length (osip_message_t * sip, const char *hvalue)
 
 int
 osip_content_length_parse (osip_content_length_t * content_length,
-			   const char *hvalue)
+                           const char *hvalue)
 {
-  if (strlen (hvalue) + 1 < 2)
+  size_t len;
+
+  if (hvalue == NULL)
     return -1;
-  content_length->value = (char *) osip_malloc (strlen (hvalue) + 1);
+  len = strlen (hvalue);
+  if (len + 1 < 2)
+    return -1;
+  content_length->value = (char *) osip_malloc (len + 1);
   if (content_length->value == NULL)
     return -1;
-  osip_strncpy (content_length->value, hvalue, strlen (hvalue));
+  osip_strncpy (content_length->value, hvalue, len);
   return 0;
 }
 
@@ -111,7 +115,7 @@ osip_content_length_free (osip_content_length_t * content_length)
 
 int
 osip_content_length_clone (const osip_content_length_t * ctl,
-			   osip_content_length_t ** dest)
+                           osip_content_length_t ** dest)
 {
   int i;
   osip_content_length_t *cl;
@@ -124,7 +128,7 @@ osip_content_length_clone (const osip_content_length_t * ctl,
      if (ctl->value==NULL) return -1;
    */
   i = osip_content_length_init (&cl);
-  if (i == -1)			/* allocation failed */
+  if (i == -1)                  /* allocation failed */
     return -1;
   if (ctl->value != NULL)
     cl->value = osip_strdup (ctl->value);
