@@ -37,8 +37,7 @@ osip_content_type_init (osip_content_type_t ** content_type)
   (*content_type)->type = NULL;
   (*content_type)->subtype = NULL;
 
-  (*content_type)->gen_params =
-    (osip_list_t *) osip_malloc (sizeof (osip_list_t));
+  (*content_type)->gen_params = (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   if ((*content_type)->gen_params == NULL)
     {
       osip_free (*content_type);
@@ -93,8 +92,7 @@ osip_message_get_content_type (const osip_message_t * sip)
 /* OUTPUT: osip_content_type_t *content_type | structure to save results.     */
 /* returns -1 on error. */
 int
-osip_content_type_parse (osip_content_type_t * content_type,
-			 const char *hvalue)
+osip_content_type_parse (osip_content_type_t * content_type, const char *hvalue)
 {
   char *subtype;
   char *osip_content_type_params;
@@ -110,20 +108,21 @@ osip_content_type_parse (osip_content_type_t * content_type,
      application/multipart ; boundary=
      ^          ^
    */
+  if (hvalue == NULL || hvalue[0] == '\0')
+    return 0;                   /* It's valid to add empty Accept header! */
 
   subtype = strchr (hvalue, '/');
   osip_content_type_params = strchr (hvalue, ';');
 
   if (subtype == NULL)
-    return -1;			/* do we really mind such an error */
+    return -1;                  /* do we really mind such an error */
 
   if (osip_content_type_params != NULL)
     {
       if (__osip_generic_param_parseall (content_type->gen_params,
-					 osip_content_type_params) == -1)
-	return -1;
-    }
-  else
+                                         osip_content_type_params) == -1)
+        return -1;
+  } else
     osip_content_type_params = subtype + strlen (subtype);
 
   if (subtype - hvalue + 1 < 2)
@@ -131,8 +130,7 @@ osip_content_type_parse (osip_content_type_t * content_type,
   content_type->type = (char *) osip_malloc (subtype - hvalue + 1);
   if (content_type->type == NULL)
     return -1;
-  osip_strncpy (content_type->type, hvalue, subtype - hvalue);
-  osip_clrspace (content_type->type);
+  osip_clrncpy (content_type->type, hvalue, subtype - hvalue);
 
   if (osip_content_type_params - subtype < 2)
     return -1;
@@ -140,9 +138,8 @@ osip_content_type_parse (osip_content_type_t * content_type,
     (char *) osip_malloc (osip_content_type_params - subtype);
   if (content_type->subtype == NULL)
     return -1;
-  osip_strncpy (content_type->subtype, subtype + 1,
-		osip_content_type_params - subtype - 1);
-  osip_clrspace (content_type->subtype);
+  osip_clrncpy (content_type->subtype, subtype + 1,
+                osip_content_type_params - subtype - 1);
 
   return 0;
 }
@@ -152,8 +149,7 @@ osip_content_type_parse (osip_content_type_t * content_type,
 /* INPUT : osip_content_type_t *content_type | content_type header.   */
 /* returns null on error. */
 int
-osip_content_type_to_str (const osip_content_type_t * content_type,
-			  char **dest)
+osip_content_type_to_str (const osip_content_type_t * content_type, char **dest)
 {
   char *buf;
   char *tmp;
@@ -165,7 +161,7 @@ osip_content_type_to_str (const osip_content_type_t * content_type,
     return -1;
 
   /* try to guess a long enough length */
-  len = strlen (content_type->type) + strlen (content_type->subtype) + 4	/* for '/', ' ', ';' and '\0' */
+  len = strlen (content_type->type) + strlen (content_type->subtype) + 4        /* for '/', ' ', ';' and '\0' */
     + 10 * osip_list_size (content_type->gen_params);
 
   buf = (char *) osip_malloc (len);
@@ -178,34 +174,35 @@ osip_content_type_to_str (const osip_content_type_t * content_type,
     int pos = 0;
     osip_generic_param_t *u_param;
 
+#if 0
     if (!osip_list_eol (content_type->gen_params, pos))
-      {				/* needed for cannonical form! (authentication issue of rfc2543) */
-	sprintf (tmp, " ");
-	tmp++;
+      {                         /* needed for cannonical form! (authentication issue of rfc2543) */
+        sprintf (tmp, " ");
+        tmp++;
       }
+#endif
     while (!osip_list_eol (content_type->gen_params, pos))
       {
-	size_t tmp_len;
+        size_t tmp_len;
 
-	u_param =
-	  (osip_generic_param_t *) osip_list_get (content_type->gen_params,
-						  pos);
-	if (u_param->gvalue == NULL)
-	  {
-	    osip_free (buf);
-	    return -1;
-	  }
-	tmp_len = strlen (buf) + 4 + strlen (u_param->gname)
-	  + strlen (u_param->gvalue);
-	if (len < tmp_len)
-	  {
-	    buf = osip_realloc (buf, tmp_len);
-	    len = tmp_len;
-	    tmp = buf + strlen (buf);
-	  }
-	sprintf (tmp, ";%s=%s", u_param->gname, u_param->gvalue);
-	tmp = tmp + strlen (tmp);
-	pos++;
+        u_param =
+          (osip_generic_param_t *) osip_list_get (content_type->gen_params, pos);
+        if (u_param->gvalue == NULL)
+          {
+            osip_free (buf);
+            return -1;
+          }
+        tmp_len = strlen (buf) + 4 + strlen (u_param->gname)
+          + strlen (u_param->gvalue) + 1;
+        if (len < tmp_len)
+          {
+            buf = osip_realloc (buf, tmp_len);
+            len = tmp_len;
+            tmp = buf + strlen (buf);
+          }
+        sprintf (tmp, "; %s=%s", u_param->gname, u_param->gvalue);
+        tmp = tmp + strlen (tmp);
+        pos++;
       }
   }
   *dest = buf;
@@ -234,7 +231,7 @@ osip_content_type_free (osip_content_type_t * content_type)
 
 int
 osip_content_type_clone (const osip_content_type_t * ctt,
-			 osip_content_type_t ** dest)
+                         osip_content_type_t ** dest)
 {
   int i;
   osip_content_type_t *ct;
@@ -242,16 +239,14 @@ osip_content_type_clone (const osip_content_type_t * ctt,
   *dest = NULL;
   if (ctt == NULL)
     return -1;
-  if (ctt->type == NULL)
-    return -1;
-  if (ctt->subtype == NULL)
-    return -1;
 
   i = osip_content_type_init (&ct);
-  if (i != 0)			/* allocation failed */
+  if (i != 0)                   /* allocation failed */
     return -1;
-  ct->type = osip_strdup (ctt->type);
-  ct->subtype = osip_strdup (ctt->subtype);
+  if (ctt->type != NULL)
+    ct->type = osip_strdup (ctt->type);
+  if (ctt->subtype != NULL)
+    ct->subtype = osip_strdup (ctt->subtype);
 
   {
     int pos = 0;
@@ -260,17 +255,16 @@ osip_content_type_clone (const osip_content_type_t * ctt,
 
     while (!osip_list_eol (ctt->gen_params, pos))
       {
-	u_param =
-	  (osip_generic_param_t *) osip_list_get (ctt->gen_params, pos);
-	i = osip_generic_param_clone (u_param, &dest_param);
-	if (i != 0)
-	  {
-	    osip_content_type_free (ct);
-	    osip_free (ct);
-	    return -1;
-	  }
-	osip_list_add (ct->gen_params, dest_param, -1);
-	pos++;
+        u_param = (osip_generic_param_t *) osip_list_get (ctt->gen_params, pos);
+        i = osip_generic_param_clone (u_param, &dest_param);
+        if (i != 0)
+          {
+            osip_content_type_free (ct);
+            osip_free (ct);
+            return -1;
+          }
+        osip_list_add (ct->gen_params, dest_param, -1);
+        pos++;
       }
   }
   *dest = ct;
