@@ -33,7 +33,7 @@
 /* returns -1 on error. */
 int
 osip_message_set_header (osip_message_t * sip, const char *hname,
-			 const char *hvalue)
+                         const char *hvalue)
 {
   osip_header_t *h;
   int i;
@@ -52,25 +52,22 @@ osip_message_set_header (osip_message_t * sip, const char *hname,
       osip_header_free (h);
       return -1;
     }
-  osip_strncpy (h->hname, hname, strlen (hname));
-  osip_clrspace (h->hname);
+  osip_clrncpy (h->hname, hname, strlen (hname));
 
   if (hvalue != NULL)
-    {				/* some headers can be null ("subject:") */
+    {                           /* some headers can be null ("subject:") */
       h->hvalue = (char *) osip_malloc (strlen (hvalue) + 1);
       if (h->hvalue == NULL)
-	{
-	  osip_header_free (h);
-	  return -1;
-	}
-      osip_strncpy (h->hvalue, hvalue, strlen (hvalue));
-      osip_clrspace (h->hvalue);
-    }
-  else
+        {
+          osip_header_free (h);
+          return -1;
+        }
+      osip_clrncpy (h->hvalue, hvalue, strlen (hvalue));
+  } else
     h->hvalue = NULL;
   sip->message_property = 2;
   osip_list_add (sip->headers, h, -1);
-  return 0;			/* ok */
+  return 0;                     /* ok */
 }
 
 /* Add a header to a SIP message at the top of the list.    */
@@ -80,7 +77,7 @@ osip_message_set_header (osip_message_t * sip, const char *hname,
 /* returns -1 on error. */
 int
 osip_message_set_topheader (osip_message_t * sip, const char *hname,
-			    const char *hvalue)
+                            const char *hvalue)
 {
   osip_header_t *h;
   int i;
@@ -99,25 +96,22 @@ osip_message_set_topheader (osip_message_t * sip, const char *hname,
       osip_header_free (h);
       return -1;
     }
-  osip_strncpy (h->hname, hname, strlen (hname));
-  osip_clrspace (h->hname);
+  osip_clrncpy (h->hname, hname, strlen (hname));
 
   if (hvalue != NULL)
-    {				/* some headers can be null ("subject:") */
+    {                           /* some headers can be null ("subject:") */
       h->hvalue = (char *) osip_malloc (strlen (hvalue) + 1);
       if (h->hvalue == NULL)
-	{
-	  osip_header_free (h);
-	  return -1;
-	}
-      osip_strncpy (h->hvalue, hvalue, strlen (hvalue));
-      osip_clrspace (h->hvalue);
-    }
-  else
+        {
+          osip_header_free (h);
+          return -1;
+        }
+      osip_clrncpy (h->hvalue, hvalue, strlen (hvalue));
+  } else
     h->hvalue = NULL;
   sip->message_property = 2;
   osip_list_add (sip->headers, h, 0);
-  return 0;			/* ok */
+  return 0;                     /* ok */
 }
 
 /* Get a header in a SIP message.                       */
@@ -126,11 +120,11 @@ osip_message_set_topheader (osip_message_t * sip, const char *hname,
 /* return null on error. */
 int
 osip_message_get_header (const osip_message_t * sip, int pos,
-			 osip_header_t ** dest)
+                         osip_header_t ** dest)
 {
   *dest = NULL;
   if (osip_list_size (sip->headers) <= pos)
-    return -1;			/* NULL */
+    return -1;                  /* NULL */
   *dest = (osip_header_t *) osip_list_get (sip->headers, pos);
   return 0;
 }
@@ -142,7 +136,7 @@ osip_message_get_header (const osip_message_t * sip, int pos,
 /* and -1 on error. */
 int
 osip_message_header_get_byname (const osip_message_t * sip, const char *hname,
-				int pos, osip_header_t ** dest)
+                                int pos, osip_header_t ** dest)
 {
   int i;
   osip_header_t *tmp;
@@ -150,18 +144,18 @@ osip_message_header_get_byname (const osip_message_t * sip, const char *hname,
   *dest = NULL;
   i = pos;
   if (osip_list_size (sip->headers) <= pos)
-    return -1;			/* NULL */
+    return -1;                  /* NULL */
   while (osip_list_size (sip->headers) > i)
     {
       tmp = (osip_header_t *) osip_list_get (sip->headers, i);
       if (osip_strcasecmp (tmp->hname, hname) == 0)
-	{
-	  *dest = tmp;
-	  return i;
-	}
+        {
+          *dest = tmp;
+          return i;
+        }
       i++;
     }
-  return -1;			/* not found */
+  return -1;                    /* not found */
 }
 
 int
@@ -214,7 +208,7 @@ osip_header_to_str (const osip_header_t * header, char **dest)
     sprintf (*dest, "%s: ", header->hname);
 
   if (*dest[0] > 'a' && *dest[0] < 'z')
-    *dest[0] = (*dest[0]-32);
+    *dest[0] = (*dest[0] - 32);
   return 0;
 }
 
