@@ -26,10 +26,10 @@
 int
 osip_list_init (osip_list_t * li)
 {
-  if (li==NULL)
+  if (li == NULL)
     return -1;
-  memset(li, 0, sizeof(osip_list_t));
-  return 0;			/* ok */
+  memset (li, 0, sizeof (osip_list_t));
+  return 0;                     /* ok */
 }
 
 void
@@ -44,8 +44,8 @@ osip_list_special_free (osip_list_t * li, void *(*free_func) (void *))
     {
       element = (void *) osip_list_get (li, pos);
       osip_list_remove (li, pos);
-      if (free_func!=NULL)
-	free_func (element);
+      if (free_func != NULL)
+        free_func (element);
     }
   osip_free (li);
 }
@@ -86,10 +86,11 @@ osip_list_size (const osip_list_t * li)
 int
 osip_list_eol (const osip_list_t * li, int i)
 {
-  if(li==NULL) return -1;
+  if (li == NULL)
+    return -1;
   if (i < li->nb_elt)
-    return 0;			/* not end of list */
-  return 1;			/* end of list */
+    return 0;                   /* not end of list */
+  return 1;                     /* end of list */
 }
 
 /* index starts from 0; */
@@ -99,13 +100,15 @@ osip_list_add (osip_list_t * li, void *el, int pos)
   __node_t *ntmp;
   int i = 0;
 
-  if (li == NULL) return -1;
+  if (li == NULL)
+    return -1;
 
   if (li->nb_elt == 0)
     {
 
       li->node = (__node_t *) osip_malloc (sizeof (__node_t));
-      if (li->node == NULL) return -1;
+      if (li->node == NULL)
+        return -1;
       li->node->element = el;
       li->node->next = NULL;
       li->nb_elt++;
@@ -113,27 +116,27 @@ osip_list_add (osip_list_t * li, void *el, int pos)
     }
 
   if (pos == -1 || pos >= li->nb_elt)
-    {				/* insert at the end  */
+    {                           /* insert at the end  */
       pos = li->nb_elt;
     }
 
-  ntmp = li->node;		/* exist because nb_elt>0  */
+  ntmp = li->node;              /* exist because nb_elt>0  */
 
-  if (pos == 0) /* pos = 0 insert before first elt  */
+  if (pos == 0)                 /* pos = 0 insert before first elt  */
     {
       li->node = (__node_t *) osip_malloc (sizeof (__node_t));
       if (li->node == NULL)
-	{
-	  /* leave the list unchanged */
-	  li->node=ntmp;
-	  return -1;
-	}
+        {
+          /* leave the list unchanged */
+          li->node = ntmp;
+          return -1;
+        }
       li->node->element = el;
       li->node->next = ntmp;
       li->nb_elt++;
       return li->nb_elt;
     }
-  
+
 
   while (pos > i + 1)
     {
@@ -146,7 +149,8 @@ osip_list_add (osip_list_t * li, void *el, int pos)
   if (pos == li->nb_elt)
     {
       ntmp->next = (__node_t *) osip_malloc (sizeof (__node_t));
-      if (ntmp->next == NULL) return -1; /* leave the list unchanged */
+      if (ntmp->next == NULL)
+        return -1;              /* leave the list unchanged */
       ntmp = (__node_t *) ntmp->next;
       ntmp->element = el;
       ntmp->next = NULL;
@@ -159,11 +163,12 @@ osip_list_add (osip_list_t * li, void *el, int pos)
     __node_t *nextnode = (__node_t *) ntmp->next;
 
     ntmp->next = (__node_t *) osip_malloc (sizeof (__node_t));
-    if (ntmp->next ==  NULL) {
-      /* leave the list unchanged */
-      ntmp->next=nextnode;
-      return -1;
-    }
+    if (ntmp->next == NULL)
+      {
+        /* leave the list unchanged */
+        ntmp->next = nextnode;
+        return -1;
+      }
     ntmp = (__node_t *) ntmp->next;
     ntmp->element = el;
     ntmp->next = nextnode;
@@ -179,14 +184,15 @@ osip_list_get (const osip_list_t * li, int pos)
   __node_t *ntmp;
   int i = 0;
 
-  if (li == NULL) return NULL;
+  if (li == NULL)
+    return NULL;
 
   if (pos < 0 || pos >= li->nb_elt)
     /* element does not exist */
     return NULL;
 
 
-  ntmp = li->node;		/* exist because nb_elt>0 */
+  ntmp = li->node;              /* exist because nb_elt>0 */
 
   while (pos > i)
     {
@@ -197,12 +203,14 @@ osip_list_get (const osip_list_t * li, int pos)
 }
 
 /* added by bennewit@cs.tu-berlin.de */
-void * osip_list_get_first( osip_list_t * li, osip_list_iterator_t * iterator )
+void *
+osip_list_get_first (osip_list_t * li, osip_list_iterator_t * iterator)
 {
-  if ( 0 >= li->nb_elt) {
-    iterator->actual = 0;
-    return 0;
-  }
+  if (0 >= li->nb_elt)
+    {
+      iterator->actual = 0;
+      return 0;
+    }
 
   iterator->actual = li->node;
   iterator->prev = &li->node;
@@ -213,35 +221,40 @@ void * osip_list_get_first( osip_list_t * li, osip_list_iterator_t * iterator )
 }
 
 /* added by bennewit@cs.tu-berlin.de */
-void * osip_list_get_next( osip_list_iterator_t * iterator )
+void *
+osip_list_get_next (osip_list_iterator_t * iterator)
 {
-  iterator->prev = (__node_t**)&(iterator->actual->next);
+  iterator->prev = (__node_t **) & (iterator->actual->next);
   iterator->actual = iterator->actual->next;
   ++(iterator->pos);
 
-  if ( osip_list_iterator_has_elem( *iterator ) ) {
-    return iterator->actual->element;
-  }
+  if (osip_list_iterator_has_elem (*iterator))
+    {
+      return iterator->actual->element;
+    }
 
   iterator->actual = 0;
   return 0;
 }
 
 /* added by bennewit@cs.tu-berlin.de */
-void * osip_list_iterator_remove( osip_list_iterator_t * iterator )
+void *
+osip_list_iterator_remove (osip_list_iterator_t * iterator)
 {
-  if ( osip_list_iterator_has_elem( *iterator ) ) {
-    --(iterator->li->nb_elt);
+  if (osip_list_iterator_has_elem (*iterator))
+    {
+      --(iterator->li->nb_elt);
 
-    *(iterator->prev) = iterator->actual->next;
+      *(iterator->prev) = iterator->actual->next;
 
-    osip_free( iterator->actual );
-    iterator->actual = *(iterator->prev);
-  }
-  
-  if ( osip_list_iterator_has_elem( *iterator ) ) {
-    return iterator->actual->element;
-  }
+      osip_free (iterator->actual);
+      iterator->actual = *(iterator->prev);
+    }
+
+  if (osip_list_iterator_has_elem (*iterator))
+    {
+      return iterator->actual->element;
+    }
 
   return 0;
 }
@@ -254,16 +267,17 @@ osip_list_remove (osip_list_t * li, int pos)
   __node_t *ntmp;
   int i = 0;
 
-  if (li == NULL) return -1;
+  if (li == NULL)
+    return -1;
 
   if (pos < 0 || pos >= li->nb_elt)
     /* element does not exist */
     return -1;
 
-  ntmp = li->node;		/* exist because nb_elt>0 */
+  ntmp = li->node;              /* exist because nb_elt>0 */
 
   if ((pos == 0))
-    {				/* special case  */
+    {                           /* special case  */
       li->node = (__node_t *) ntmp->next;
       li->nb_elt--;
       osip_free (ntmp);
