@@ -26,6 +26,16 @@
 
 static __osip_message_config_t pconfig[NUMBER_OF_HEADERS];
 
+/* The size of the hash table seems large for a limited number of possible entries
+ * The 'problem' is that the header name are too much alike for the osip_hash() function
+ * which gives a poor deviation.
+ * Anyway, this mechanism improves the search time (from binary seach (log(n)) to 1).
+ */
+
+#define HASH_TABLE_SIZE 150     /* set this to the hash table size, 150 is the first size
+                                   where no conflicts occur                               */
+static int hdr_ref_table[HASH_TABLE_SIZE];      /* the hashtable contains indices to the pconfig table    */
+
 /*
   list of compact header:
   i: Call-ID   => ok
@@ -41,7 +51,7 @@ static __osip_message_config_t pconfig[NUMBER_OF_HEADERS];
 */
 /* This method must be called before using the parser */
 int
-parser_init ()
+parser_init (void)
 {
   int i = 0;
 
@@ -59,7 +69,7 @@ parser_init ()
   pconfig[i++].setheader = (&osip_message_set_authentication_info);
   pconfig[i].hname = AUTHORIZATION;
   pconfig[i++].setheader = (&osip_message_set_authorization);
-  pconfig[i].hname = CONTENT_TYPE_SHORT;	/* "l" */
+  pconfig[i].hname = CONTENT_TYPE_SHORT;        /* "l" */
   pconfig[i++].setheader = (&osip_message_set_content_type);
   pconfig[i].hname = CALL_ID;
   pconfig[i++].setheader = (&osip_message_set_call_id);
@@ -75,19 +85,19 @@ parser_init ()
   pconfig[i++].setheader = (&osip_message_set_content_type);
   pconfig[i].hname = CSEQ;
   pconfig[i++].setheader = (&osip_message_set_cseq);
-  pconfig[i].hname = CONTENT_ENCODING_SHORT;	/* "e" */
+  pconfig[i].hname = CONTENT_ENCODING_SHORT;    /* "e" */
   pconfig[i++].setheader = (&osip_message_set_content_encoding);
   pconfig[i].hname = ERROR_INFO;
   pconfig[i++].setheader = (&osip_message_set_error_info);
-  pconfig[i].hname = FROM_SHORT;	/* "f" */
+  pconfig[i].hname = FROM_SHORT;        /* "f" */
   pconfig[i++].setheader = (&osip_message_set_from);
   pconfig[i].hname = FROM;
   pconfig[i++].setheader = (&osip_message_set_from);
-  pconfig[i].hname = CALL_ID_SHORT;	/* "i" */
+  pconfig[i].hname = CALL_ID_SHORT;     /* "i" */
   pconfig[i++].setheader = (&osip_message_set_call_id);
-  pconfig[i].hname = CONTENT_LENGTH_SHORT;	/* "l" */
+  pconfig[i].hname = CONTENT_LENGTH_SHORT;      /* "l" */
   pconfig[i++].setheader = (&osip_message_set_content_length);
-  pconfig[i].hname = CONTACT_SHORT;	/* "m" */
+  pconfig[i].hname = CONTACT_SHORT;     /* "m" */
   pconfig[i++].setheader = (&osip_message_set_contact);
   pconfig[i].hname = MIME_VERSION;
   pconfig[i++].setheader = (&osip_message_set_mime_version);
@@ -112,74 +122,57 @@ parser_init ()
   pconfig[i].hname = WWW_AUTHENTICATE;
   pconfig[i++].setheader = (&osip_message_set_www_authenticate);
 
+  /* build up hash table for fast header lookup */
+
+  /* initialize the table */
+  for (i = 0; i < HASH_TABLE_SIZE; i++)
+    {
+      hdr_ref_table[i] = -1;    /* -1 -> no entry */
+    }
+
+  for (i = 0; i < NUMBER_OF_HEADERS; i++)
+    {
+      unsigned long hash;
+
+      /* calculate hash value using lower case */
+      /* Fixed: do not lower constant... osip_tolower( pconfig[i].hname ); */
+      hash = osip_hash (pconfig[i].hname);
+      hash = hash % HASH_TABLE_SIZE;
+
+      if (hdr_ref_table[hash] == -1)
+        {
+          /* store reference(index) to pconfig table */
+          hdr_ref_table[hash] = i;
+      } else
+        {
+          /* oops, conflict!-> change the hash table or use another hash function size */
+          return -1;
+        }
+    }
+
   return 0;
 }
 
-/* search the header hname through pconfig[] tab. 
-   A quicker algorithm should be used.
-   It returns the index of the header in the __osip_message_config_t tab.
-*/
+/* improved look-up mechanism
+   precondition: hname is all lowercase */
 int
 __osip_message_is_known_header (const char *hname)
 {
-  size_t length;
-  int iinf = 0;
-  int isup = NUMBER_OF_HEADERS;
-  int i = NUMBER_OF_HEADERS / 2;
+  unsigned long hash;
+  int result = -1;
 
-  length = strlen (hname);
+  int index;
 
-  for (;;)
+  hash = osip_hash (hname);
+  hash = hash % HASH_TABLE_SIZE;
+  index = hdr_ref_table[hash];
+
+  if ((index != -1) && (0 == strcmp (pconfig[index].hname, hname)))
     {
-      if (i < 0 || i > NUMBER_OF_HEADERS - 1)
-	return -1;
+      result = index;
+    }
 
-      if ((length == strlen (pconfig[i].hname))
-	  && osip_strncasecmp (hname, (const char *) pconfig[i].hname,
-			       length) == 0)
-	return i;
-
-      if (iinf == isup)
-	return -1;		/* not found */
-      if (iinf == isup - 1)
-	{
-	  if ((i < NUMBER_OF_HEADERS - 1)
-	      && (length == strlen (pconfig[i + 1].hname))
-	      && osip_strncasecmp (hname,
-				   (const char *) pconfig[i + 1].hname,
-				   length) == 0)
-	    return i + 1;
-	  else
-	    return -1;
-/* Unreachable code??
-	  if ((i > 0) && (length == strlen (pconfig[i - 1].hname))
-	      && osip_strncasecmp (hname,
-			  (const char *) pconfig[i - 1].hname, length) == 0)
-	    return i - 1;
-	  else
-	    return -1;
-*/
-	}
-      if (0 < osip_strncasecmp (hname,
-				(const char *) pconfig[i].hname, length))
-	{
-	  /* if this is true, search further */
-	  iinf = i;
-	  if (i == i + (isup - i) / 2)
-	    i++;
-	  else
-	    i = i + (isup - i) / 2;
-	}
-      else
-	{
-	  isup = i;
-	  if (i == i - (i - iinf) / 2)
-	    i--;
-	  else
-	    i = i - (i - iinf) / 2;
-	}
-    }				/* end of (while (1)) */
-  return -1;
+  return result;
 }
 
 #else /* USE_GPERF */
@@ -306,18 +299,18 @@ static const __osip_message_config_t pconfig[133] = {
   {"", NULL},
   {AUTHORIZATION, &osip_message_set_authorization},
   {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"",
-									   NULL},
+                                                                           NULL},
   {RETRY_AFTER, NULL},
   {"", NULL}, {"", NULL},
   {CONTENT_DISPOSITION, NULL},
   {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"",
-									   NULL},
+                                                                           NULL},
   {"", NULL}, {"", NULL},
   {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"",
-									   NULL},
+                                                                           NULL},
   {CONTACT_SHORT, &osip_message_set_contact},
   {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"", NULL}, {"",
-									   NULL},
+                                                                           NULL},
   {"", NULL}, {"", NULL},
   {"", NULL},
   {MIME_VERSION, &osip_message_set_mime_version}
@@ -344,13 +337,13 @@ in_word_set (str, len)
       register int key = hash (str, len);
 
       if (key <= MAX_HASH_VALUE && key >= 0)
-	{
-	  register const char *s = pconfig[key].hname;
+        {
+          register const char *s = pconfig[key].hname;
 
-	  if (*str == *s && !strcmp (str + 1, s + 1)
-	      && (pconfig[key].setheader != NULL))
-	    return key;
-	}
+          if (*str == *s && !strcmp (str + 1, s + 1)
+              && (pconfig[key].setheader != NULL))
+            return key;
+        }
     }
   return -1;
 }
@@ -358,7 +351,7 @@ in_word_set (str, len)
 int
 parser_init ()
 {
-  return 0;			/* do not need initialization when using gperf */
+  return 0;                     /* do not need initialization when using gperf */
 }
 
 int
