@@ -30,12 +30,13 @@
 /* OUTPUT: osip_message_t *sip | structure to save results. */
 /* returns -1 on error. */
 int
-osip_message_set_proxy_authentication_info (osip_message_t * sip, const char *hvalue)
+osip_message_set_proxy_authentication_info (osip_message_t * sip,
+                                            const char *hvalue)
 {
   osip_proxy_authentication_info_t *proxy_authentication_info;
   int i;
 
-  if (hvalue==NULL || hvalue[0]=='\0')
+  if (hvalue == NULL || hvalue[0] == '\0')
     return 0;
 
   i = osip_proxy_authentication_info_init (&(proxy_authentication_info));
@@ -59,14 +60,16 @@ osip_message_set_proxy_authentication_info (osip_message_t * sip, const char *hv
 /* INPUT : osip_message_t *sip | sip message.   */
 /* returns null on error. */
 int
-osip_message_get_proxy_authentication_info (const osip_message_t * sip, int pos,
-			   osip_proxy_authentication_info_t ** dest)
+osip_message_get_proxy_authentication_info (const osip_message_t * sip,
+                                            int pos,
+                                            osip_proxy_authentication_info_t
+                                            ** dest)
 {
   osip_proxy_authentication_info_t *proxy_authentication_info;
 
   *dest = NULL;
   if (osip_list_size (sip->proxy_authentication_infos) <= pos)
-    return -1;			/* does not exist */
+    return -1;                  /* does not exist */
 
   proxy_authentication_info = (osip_proxy_authentication_info_t *)
     osip_list_get (sip->proxy_authentication_infos, pos);
