@@ -62,22 +62,20 @@ osip_message_set_record_route (osip_message_t * sip, const char *hvalue)
 /* returns null on error. */
 int
 osip_message_get_record_route (const osip_message_t * sip, int pos,
-			       osip_record_route_t ** dest)
+                               osip_record_route_t ** dest)
 {
   osip_record_route_t *record_route;
 
   *dest = NULL;
   if (osip_list_size (sip->record_routes) <= pos)
-    return -1;			/* does not exist */
-  record_route =
-    (osip_record_route_t *) osip_list_get (sip->record_routes, pos);
+    return -1;                  /* does not exist */
+  record_route = (osip_record_route_t *) osip_list_get (sip->record_routes, pos);
   *dest = record_route;
   return pos;
 }
 
 int
-osip_record_route_parse (osip_record_route_t * record_route,
-			 const char *hvalue)
+osip_record_route_parse (osip_record_route_t * record_route, const char *hvalue)
 {
   return osip_from_parse ((osip_from_t *) record_route, hvalue);
 }
@@ -86,8 +84,7 @@ osip_record_route_parse (osip_record_route_t * record_route,
 /* INPUT : osip_record_route_t *record_route | record_route header.  */
 /* returns -1 on error. */
 int
-osip_record_route_to_str (const osip_record_route_t * record_route,
-			  char **dest)
+osip_record_route_to_str (const osip_record_route_t * record_route, char **dest)
 {
   char *url;
   char *buf;
@@ -129,23 +126,22 @@ osip_record_route_to_str (const osip_record_route_t * record_route,
 
     while (!osip_list_eol (record_route->gen_params, pos))
       {
-	u_param =
-	  (osip_generic_param_t *) osip_list_get (record_route->gen_params,
-						  pos);
+        u_param =
+          (osip_generic_param_t *) osip_list_get (record_route->gen_params, pos);
 
-	if (u_param->gvalue == NULL)
-	  plen = strlen (u_param->gname) + 2;
-	else
-	  plen = strlen (u_param->gname) + strlen (u_param->gvalue) + 3;
-	len = len + plen;
-	buf = (char *) osip_realloc (buf, len);
-	tmp = buf;
-	tmp = tmp + strlen (tmp);
-	if (u_param->gvalue == NULL)
-	  sprintf (tmp, ";%s", u_param->gname);
-	else
-	  sprintf (tmp, ";%s=%s", u_param->gname, u_param->gvalue);
-	pos++;
+        if (u_param->gvalue == NULL)
+          plen = strlen (u_param->gname) + 2;
+        else
+          plen = strlen (u_param->gname) + strlen (u_param->gvalue) + 3;
+        len = len + plen;
+        buf = (char *) osip_realloc (buf, len);
+        tmp = buf;
+        tmp = tmp + strlen (tmp);
+        if (u_param->gvalue == NULL)
+          sprintf (tmp, ";%s", u_param->gname);
+        else
+          sprintf (tmp, ";%s=%s", u_param->gname, u_param->gvalue);
+        pos++;
       }
   }
   *dest = buf;
