@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -24,13 +24,8 @@
 #include <osipparser2/osip_message.h>
 #include <osipparser2/osip_parser.h>
 
-#ifdef __VXWORKS_OS__
-int
-osip_route_init2 (osip_route_t ** route)
-#else
 int
 osip_route_init (osip_route_t ** route)
-#endif
 {
   return osip_from_init ((osip_from_t **) route);
 }
@@ -70,14 +65,13 @@ osip_message_set_route (osip_message_t * sip, const char *hvalue)
 /* INPUT : osip_message_t *sip | sip message.   */
 /* returns null on error. */
 int
-osip_message_get_route (const osip_message_t * sip, int pos,
-			osip_route_t ** dest)
+osip_message_get_route (const osip_message_t * sip, int pos, osip_route_t ** dest)
 {
   osip_route_t *route;
 
   *dest = NULL;
   if (osip_list_size (sip->routes) <= pos)
-    return -1;			/* does not exist */
+    return -1;                  /* does not exist */
   route = (osip_route_t *) osip_list_get (sip->routes, pos);
   *dest = route;
   return pos;
