@@ -30,11 +30,10 @@ int
 osip_www_authenticate_init (osip_www_authenticate_t ** dest)
 {
   *dest =
-    (osip_www_authenticate_t *)
-    osip_malloc (sizeof (osip_www_authenticate_t));
+    (osip_www_authenticate_t *) osip_malloc (sizeof (osip_www_authenticate_t));
   if (*dest == NULL)
     return -1;
-  memset(*dest, 0, sizeof(osip_www_authenticate_t));
+  memset (*dest, 0, sizeof (osip_www_authenticate_t));
   return 0;
 }
 
@@ -69,131 +68,130 @@ osip_message_set_www_authenticate (osip_message_t * sip, const char *hvalue)
 
 int
 __osip_quoted_string_set (const char *name, const char *str,
-			  char **result, const char **next)
+                          char **result, const char **next)
 {
   *next = str;
   if (*result != NULL)
-    return 0;			/* already parsed */
+    return 0;                   /* already parsed */
   *next = NULL;
   while ((' ' == *str) || ('\t' == *str) || (',' == *str))
     if (*str)
       str++;
     else
-      return -1;		/* bad header format */
+      return -1;                /* bad header format */
 
   if (strlen (str) <= strlen (name))
-    return -1;			/* bad header format... */
+    return -1;                  /* bad header format... */
   if (osip_strncasecmp (name, str, strlen (name)) == 0)
     {
       const char *quote1;
       const char *quote2;
       const char *tmp;
       const char *hack = strchr (str, '=');
-      
+
       if (hack == NULL)
         return -1;
 
-      while (' ' == *(hack - 1))	/* get rid of extra spaces */
-	hack--;
+      while (' ' == *(hack - 1))        /* get rid of extra spaces */
+        hack--;
       if ((size_t) (hack - str) != strlen (name))
-	{
-	  *next = str;
-	  return 0;
-	}
+        {
+          *next = str;
+          return 0;
+        }
 
       quote1 = __osip_quote_find (str);
       if (quote1 == NULL)
-	return -1;		/* bad header format... */
+        return -1;              /* bad header format... */
       quote2 = __osip_quote_find (quote1 + 1);
       if (quote2 == NULL)
-	return -1;		/* bad header format... */
+        return -1;              /* bad header format... */
       if (quote2 - quote1 == 1)
-	{
-	  /* this is a special case! The quote contains nothing! */
-	  /* example:   Digest opaque="",cnonce=""               */
-	  /* in this case, we just forget the parameter... this  */
-	  /* this should prevent from user manipulating empty    */
-	  /* strings */
-	  tmp = quote2 + 1;	/* next element start here */
-	  for (; *tmp == ' ' || *tmp == '\t'; tmp++)
-	    {
-	    }
-	  for (; *tmp == '\n' || *tmp == '\r'; tmp++)
-	    {
-	    }			/* skip LWS */
-	  *next = NULL;
-	  if (*tmp == '\0')	/* end of header detected */
-	    return 0;
-	  if (*tmp != '\t' && *tmp != ' ')
-	    /* LWS here ? */
-	    *next = tmp;
-	  else
-	    {			/* it is: skip it... */
-	      for (; *tmp == ' ' || *tmp == '\t'; tmp++)
-		{
-		}
-	      if (*tmp == '\0')	/* end of header detected */
-		return 0;
-	      *next = tmp;
-	    }
-	  return 0;
-	}
+        {
+          /* this is a special case! The quote contains nothing! */
+          /* example:   Digest opaque="",cnonce=""               */
+          /* in this case, we just forget the parameter... this  */
+          /* this should prevent from user manipulating empty    */
+          /* strings */
+          tmp = quote2 + 1;     /* next element start here */
+          for (; *tmp == ' ' || *tmp == '\t'; tmp++)
+            {
+            }
+          for (; *tmp == '\n' || *tmp == '\r'; tmp++)
+            {
+            }                   /* skip LWS */
+          *next = NULL;
+          if (*tmp == '\0')     /* end of header detected */
+            return 0;
+          if (*tmp != '\t' && *tmp != ' ')
+            /* LWS here ? */
+            *next = tmp;
+          else
+            {                   /* it is: skip it... */
+              for (; *tmp == ' ' || *tmp == '\t'; tmp++)
+                {
+                }
+              if (*tmp == '\0') /* end of header detected */
+                return 0;
+              *next = tmp;
+            }
+          return 0;
+        }
       *result = (char *) osip_malloc (quote2 - quote1 + 3);
       if (*result == NULL)
-	return -1;
+        return -1;
       osip_strncpy (*result, quote1, quote2 - quote1 + 1);
-      tmp = quote2 + 1;		/* next element start here */
+      tmp = quote2 + 1;         /* next element start here */
       for (; *tmp == ' ' || *tmp == '\t'; tmp++)
-	{
-	}
+        {
+        }
       for (; *tmp == '\n' || *tmp == '\r'; tmp++)
-	{
-	}			/* skip LWS */
+        {
+        }                       /* skip LWS */
       *next = NULL;
-      if (*tmp == '\0')		/* end of header detected */
-	return 0;
+      if (*tmp == '\0')         /* end of header detected */
+        return 0;
       if (*tmp != '\t' && *tmp != ' ')
-	/* LWS here ? */
-	*next = tmp;
+        /* LWS here ? */
+        *next = tmp;
       else
-	{			/* it is: skip it... */
-	  for (; *tmp == ' ' || *tmp == '\t'; tmp++)
-	    {
-	    }
-	  if (*tmp == '\0')	/* end of header detected */
-	    return 0;
-	  *next = tmp;
-	}
-    }
-  else
-    *next = str;		/* wrong header asked! */
+        {                       /* it is: skip it... */
+          for (; *tmp == ' ' || *tmp == '\t'; tmp++)
+            {
+            }
+          if (*tmp == '\0')     /* end of header detected */
+            return 0;
+          *next = tmp;
+        }
+  } else
+    *next = str;                /* wrong header asked! */
   return 0;
 }
 
 int
 __osip_token_set (const char *name, const char *str, char **result,
-		  const char **next)
+                  const char **next)
 {
   const char *beg;
   const char *tmp;
 
   *next = str;
   if (*result != NULL)
-    return 0;			/* already parsed */
+    return 0;                   /* already parsed */
   *next = NULL;
 
   beg = strchr (str, '=');
   if (beg == NULL)
-    return -1;			/* bad header format... */
+    return -1;                  /* bad header format... */
 
   if (strlen (str) < 6)
-    return 0;			/* end of header... */
+    return 0;                   /* end of header... */
 
   while ((' ' == *str) || ('\t' == *str) || (',' == *str))
     if (*str)
       str++;
     else
-      return -1;		/* bad header format */
+      return -1;                /* bad header format */
 
   if (osip_strncasecmp (name, str, strlen (name)) == 0)
     {
@@ -201,42 +199,40 @@ __osip_token_set (const char *name, const char *str, char **result,
 
       end = strchr (str, ',');
       if (end == NULL)
-	end = str + strlen (str);	/* This is the end of the header */
+        end = str + strlen (str);       /* This is the end of the header */
 
       if (end - beg < 2)
-	return -1;
+        return -1;
       *result = (char *) osip_malloc (end - beg);
       if (*result == NULL)
-	return -1;
-      osip_strncpy (*result, beg + 1, end - beg - 1);
-      osip_clrspace (*result);
+        return -1;
+      osip_clrncpy (*result, beg + 1, end - beg - 1);
 
       /* make sure the element does not contain more parameter */
       tmp = (*end) ? (end + 1) : end;
       for (; *tmp == ' ' || *tmp == '\t'; tmp++)
-	{
-	}
+        {
+        }
       for (; *tmp == '\n' || *tmp == '\r'; tmp++)
-	{
-	}			/* skip LWS */
+        {
+        }                       /* skip LWS */
       *next = NULL;
-      if (*tmp == '\0')		/* end of header detected */
-	return 0;
+      if (*tmp == '\0')         /* end of header detected */
+        return 0;
       if (*tmp != '\t' && *tmp != ' ')
-	/* LWS here ? */
-	*next = tmp;
+        /* LWS here ? */
+        *next = tmp;
       else
-	{			/* it is: skip it... */
-	  for (; *tmp == ' ' || *tmp == '\t'; tmp++)
-	    {
-	    }
-	  if (*tmp == '\0')	/* end of header detected */
-	    return 0;
-	  *next = tmp;
-	}
-    }
-  else
-    *next = str;		/* next element start here */
+        {                       /* it is: skip it... */
+          for (; *tmp == ' ' || *tmp == '\t'; tmp++)
+            {
+            }
+          if (*tmp == '\0')     /* end of header detected */
+            return 0;
+          *next = tmp;
+        }
+  } else
+    *next = str;                /* next element start here */
   return 0;
 }
 
@@ -249,13 +245,12 @@ __osip_token_set (const char *name, const char *str, char **result,
    verify many situations (extra SP....)
 */
 int
-osip_www_authenticate_parse (osip_www_authenticate_t * wwwa,
-			     const char *hvalue)
+osip_www_authenticate_parse (osip_www_authenticate_t * wwwa, const char *hvalue)
 {
   const char *space;
   const char *next = NULL;
 
-  space = strchr (hvalue, ' ');	/* SEARCH FOR SPACE */
+  space = strchr (hvalue, ' '); /* SEARCH FOR SPACE */
   if (space == NULL)
     return -1;
 
@@ -271,100 +266,98 @@ osip_www_authenticate_parse (osip_www_authenticate_t * wwwa,
       int parse_ok = 0;
 
       if (__osip_quoted_string_set ("realm", space, &(wwwa->realm), &next))
-	return -1;
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
+        {
+          space = next;
+          parse_ok++;
+        }
       if (__osip_quoted_string_set ("domain", space, &(wwwa->domain), &next))
-	return -1;
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
+        {
+          space = next;
+          parse_ok++;
+        }
       if (__osip_quoted_string_set ("nonce", space, &(wwwa->nonce), &next))
-	return -1;
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
+        {
+          space = next;
+          parse_ok++;
+        }
       if (__osip_quoted_string_set ("opaque", space, &(wwwa->opaque), &next))
-	return -1;
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
+        {
+          space = next;
+          parse_ok++;
+        }
       if (__osip_token_set ("stale", space, &(wwwa->stale), &next))
-	return -1;
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
+        {
+          space = next;
+          parse_ok++;
+        }
       if (__osip_token_set ("algorithm", space, &(wwwa->algorithm), &next))
-	return -1;
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
-      if (__osip_quoted_string_set
-	  ("qop", space, &(wwwa->qop_options), &next))
-	return -1;
+        {
+          space = next;
+          parse_ok++;
+        }
+      if (__osip_quoted_string_set ("qop", space, &(wwwa->qop_options), &next))
+        return -1;
       if (next == NULL)
-	return 0;		/* end of header detected! */
+        return 0;               /* end of header detected! */
       else if (next != space)
-	{
-	  space = next;
-	  parse_ok++;
-	}
+        {
+          space = next;
+          parse_ok++;
+        }
       if (0 == parse_ok)
-	{
-	  char *quote1, *quote2, *tmp;
+        {
+          char *quote1, *quote2, *tmp;
 
-	  /* CAUTION */
-	  /* parameter not understood!!! I'm too lazy to handle IT */
-	  /* let's simply bypass it */
-	  if (strlen (space) < 1)
-	    return 0;
-	  tmp = strchr (space + 1, ',');
-	  if (tmp == NULL)	/* it was the last header */
-	    return 0;
-	  quote1 = __osip_quote_find (space);
-	  if ((quote1 != NULL) && (quote1 < tmp))	/* this may be a quoted string! */
-	    {
-	      quote2 = __osip_quote_find (quote1 + 1);
-	      if (quote2 == NULL)
-		return -1;	/* bad header format... */
-	      if (tmp < quote2)	/* the comma is inside the quotes! */
-		space = strchr (quote2, ',');
-	      else
-		space = tmp;
-	      if (space == NULL)	/* it was the last header */
-		return 0;
-	    }
-	  else
-	    space = tmp;
-	  /* continue parsing... */
-	}
+          /* CAUTION */
+          /* parameter not understood!!! I'm too lazy to handle IT */
+          /* let's simply bypass it */
+          if (strlen (space) < 1)
+            return 0;
+          tmp = strchr (space + 1, ',');
+          if (tmp == NULL)      /* it was the last header */
+            return 0;
+          quote1 = __osip_quote_find (space);
+          if ((quote1 != NULL) && (quote1 < tmp))       /* this may be a quoted string! */
+            {
+              quote2 = __osip_quote_find (quote1 + 1);
+              if (quote2 == NULL)
+                return -1;      /* bad header format... */
+              if (tmp < quote2) /* the comma is inside the quotes! */
+                space = strchr (quote2, ',');
+              else
+                space = tmp;
+              if (space == NULL)        /* it was the last header */
+                return 0;
+          } else
+            space = tmp;
+          /* continue parsing... */
+        }
     }
-  return 0;			/* ok */
+  return 0;                     /* ok */
 }
 
 /* returns the www_authenticate header.            */
@@ -372,13 +365,13 @@ osip_www_authenticate_parse (osip_www_authenticate_t * wwwa,
 /* returns null on error. */
 int
 osip_message_get_www_authenticate (const osip_message_t * sip, int pos,
-				   osip_www_authenticate_t ** dest)
+                                   osip_www_authenticate_t ** dest)
 {
   osip_www_authenticate_t *www_authenticate;
 
   *dest = NULL;
   if (osip_list_size (sip->www_authenticates) <= pos)
-    return -1;			/* does not exist */
+    return -1;                  /* does not exist */
 
   www_authenticate =
     (osip_www_authenticate_t *) osip_list_get (sip->www_authenticates, pos);
@@ -388,15 +381,14 @@ osip_message_get_www_authenticate (const osip_message_t * sip, int pos,
 }
 
 char *
-osip_www_authenticate_get_auth_type (osip_www_authenticate_t *
-				     www_authenticate)
+osip_www_authenticate_get_auth_type (osip_www_authenticate_t * www_authenticate)
 {
   return www_authenticate->auth_type;
 }
 
 void
 osip_www_authenticate_set_auth_type (osip_www_authenticate_t *
-				     www_authenticate, char *auth_type)
+                                     www_authenticate, char *auth_type)
 {
   www_authenticate->auth_type = (char *) auth_type;
 }
@@ -409,7 +401,7 @@ osip_www_authenticate_get_realm (osip_www_authenticate_t * www_authenticate)
 
 void
 osip_www_authenticate_set_realm (osip_www_authenticate_t * www_authenticate,
-				 char *realm)
+                                 char *realm)
 {
   www_authenticate->realm = (char *) realm;
 }
@@ -422,7 +414,7 @@ osip_www_authenticate_get_domain (osip_www_authenticate_t * www_authenticate)
 
 void
 osip_www_authenticate_set_domain (osip_www_authenticate_t * www_authenticate,
-				  char *domain)
+                                  char *domain)
 {
   www_authenticate->domain = (char *) domain;
 }
@@ -435,7 +427,7 @@ osip_www_authenticate_get_nonce (osip_www_authenticate_t * www_authenticate)
 
 void
 osip_www_authenticate_set_nonce (osip_www_authenticate_t * www_authenticate,
-				 char *nonce)
+                                 char *nonce)
 {
   www_authenticate->nonce = (char *) nonce;
 }
@@ -448,7 +440,7 @@ osip_www_authenticate_get_stale (osip_www_authenticate_t * www_authenticate)
 
 void
 osip_www_authenticate_set_stale (osip_www_authenticate_t * www_authenticate,
-				 char *stale)
+                                 char *stale)
 {
   www_authenticate->stale = (char *) stale;
 }
@@ -461,35 +453,33 @@ osip_www_authenticate_get_opaque (osip_www_authenticate_t * www_authenticate)
 
 void
 osip_www_authenticate_set_opaque (osip_www_authenticate_t * www_authenticate,
-				  char *opaque)
+                                  char *opaque)
 {
   www_authenticate->opaque = (char *) opaque;
 }
 
 char *
-osip_www_authenticate_get_algorithm (osip_www_authenticate_t *
-				     www_authenticate)
+osip_www_authenticate_get_algorithm (osip_www_authenticate_t * www_authenticate)
 {
   return www_authenticate->algorithm;
 }
 
 void
 osip_www_authenticate_set_algorithm (osip_www_authenticate_t *
-				     www_authenticate, char *algorithm)
+                                     www_authenticate, char *algorithm)
 {
   www_authenticate->algorithm = (char *) algorithm;
 }
 
 char *
-osip_www_authenticate_get_qop_options (osip_www_authenticate_t *
-				       www_authenticate)
+osip_www_authenticate_get_qop_options (osip_www_authenticate_t * www_authenticate)
 {
   return www_authenticate->qop_options;
 }
 
 void
 osip_www_authenticate_set_qop_options (osip_www_authenticate_t *
-				       www_authenticate, char *qop_options)
+                                       www_authenticate, char *qop_options)
 {
   www_authenticate->qop_options = (char *) qop_options;
 }
@@ -500,8 +490,7 @@ osip_www_authenticate_set_qop_options (osip_www_authenticate_t *
 /* INPUT : osip_www_authenticate_t *www_authenticate | www_authenticate header.  */
 /* returns null on error. */
 int
-osip_www_authenticate_to_str (const osip_www_authenticate_t * wwwa,
-			      char **dest)
+osip_www_authenticate_to_str (const osip_www_authenticate_t * wwwa, char **dest)
 {
   size_t len;
   char *tmp;
@@ -533,57 +522,42 @@ osip_www_authenticate_to_str (const osip_www_authenticate_t * wwwa,
     return -1;
   *dest = tmp;
 
-  osip_strncpy (tmp, wwwa->auth_type, strlen (wwwa->auth_type));
-  tmp = tmp + strlen (tmp);
+  tmp = osip_str_append (tmp, wwwa->auth_type);
 
   if (wwwa->realm != NULL)
     {
-      osip_strncpy (tmp, " realm=", 7);
-      tmp = tmp + 7;
-      osip_strncpy (tmp, wwwa->realm, strlen (wwwa->realm));
-      tmp = tmp + strlen (tmp);
+      tmp = osip_strn_append (tmp, " realm=", 7);
+      tmp = osip_str_append (tmp, wwwa->realm);
     }
   if (wwwa->domain != NULL)
     {
-      osip_strncpy (tmp, ", domain=", 9);
-      tmp = tmp + 9;
-      osip_strncpy (tmp, wwwa->domain, strlen (wwwa->domain));
-      tmp = tmp + strlen (tmp);
+      tmp = osip_strn_append (tmp, ", domain=", 9);
+      tmp = osip_str_append (tmp, wwwa->domain);
     }
   if (wwwa->nonce != NULL)
     {
-      osip_strncpy (tmp, ", nonce=", 8);
-      tmp = tmp + 8;
-      osip_strncpy (tmp, wwwa->nonce, strlen (wwwa->nonce));
-      tmp = tmp + strlen (tmp);
+      tmp = osip_strn_append (tmp, ", nonce=", 8);
+      tmp = osip_str_append (tmp, wwwa->nonce);
     }
   if (wwwa->opaque != NULL)
     {
-      osip_strncpy (tmp, ", opaque=", 9);
-      tmp = tmp + 9;
-      osip_strncpy (tmp, wwwa->opaque, strlen (wwwa->opaque));
-      tmp = tmp + strlen (tmp);
+      tmp = osip_strn_append (tmp, ", opaque=", 9);
+      tmp = osip_str_append (tmp, wwwa->opaque);
     }
   if (wwwa->stale != NULL)
     {
-      osip_strncpy (tmp, ", stale=", 8);
-      tmp = tmp + 8;
-      osip_strncpy (tmp, wwwa->stale, strlen (wwwa->stale));
-      tmp = tmp + strlen (tmp);
+      tmp = osip_strn_append (tmp, ", stale=", 8);
+      tmp = osip_str_append (tmp, wwwa->stale);
     }
   if (wwwa->algorithm != NULL)
     {
-      osip_strncpy (tmp, ", algorithm=", 12);
-      tmp = tmp + 12;
-      osip_strncpy (tmp, wwwa->algorithm, strlen (wwwa->algorithm));
-      tmp = tmp + strlen (tmp);
+      tmp = osip_strn_append (tmp, ", algorithm=", 12);
+      tmp = osip_str_append (tmp, wwwa->algorithm);
     }
   if (wwwa->qop_options != NULL)
     {
-      osip_strncpy (tmp, ", qop=", 6);
-      tmp = tmp + 6;
-      osip_strncpy (tmp, wwwa->qop_options, strlen (wwwa->qop_options));
-      tmp = tmp + strlen (tmp);
+      tmp = osip_strn_append (tmp, ", qop=", 6);
+      tmp = osip_str_append (tmp, wwwa->qop_options);
     }
 
   if (wwwa->realm == NULL)
@@ -591,7 +565,7 @@ osip_www_authenticate_to_str (const osip_www_authenticate_t * wwwa,
       /* remove comma */
       len = strlen (wwwa->auth_type);
       if ((*dest)[len] == ',')
-	(*dest)[len] = ' ';
+        (*dest)[len] = ' ';
     }
 
   return 0;
@@ -619,7 +593,7 @@ osip_www_authenticate_free (osip_www_authenticate_t * www_authenticate)
 
 int
 osip_www_authenticate_clone (const osip_www_authenticate_t * wwwa,
-			     osip_www_authenticate_t ** dest)
+                             osip_www_authenticate_t ** dest)
 {
   int i;
   osip_www_authenticate_t *wa;
@@ -631,7 +605,7 @@ osip_www_authenticate_clone (const osip_www_authenticate_t * wwwa,
     return -1;
 
   i = osip_www_authenticate_init (&wa);
-  if (i == -1)			/* allocation failed */
+  if (i == -1)                  /* allocation failed */
     return -1;
   wa->auth_type = osip_strdup (wwwa->auth_type);
   if (wwwa->realm != NULL)
